# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dashboard.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import annotations_pb2 as annotations__pb2
from . import account_pb2 as account__pb2
from . import discussions_pb2 as discussions__pb2
from . import events_pb2 as events__pb2
from . import requests_pb2 as requests__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0f\x64\x61shboard.proto\x12\x1aorg.couchers.api.dashboard\x1a\x11\x61nnotations.proto\x1a\raccount.proto\x1a\x11\x64iscussions.proto\x1a\x0c\x65vents.proto\x1a\x0erequests.proto\"\x13\n\x11GetDashboardV2Req\"\xa8\x03\n\x11GetDashboardV2Res\x12<\n\treminders\x18\x01 \x01(\x0b\x32).org.couchers.api.account.GetRemindersRes\x12?\n\x07surfing\x18\x02 \x01(\x0b\x32..org.couchers.api.requests.ListHostRequestsRes\x12?\n\x07hosting\x18\x03 \x01(\x0b\x32..org.couchers.api.requests.ListHostRequestsRes\x12;\n\tmy_events\x18\x04 \x01(\x0b\x32(.org.couchers.api.events.ListMyEventsRes\x12\x42\n\x10\x63ommunity_events\x18\x05 \x01(\x0b\x32(.org.couchers.api.events.ListMyEventsRes\x12R\n\x0b\x64iscussions\x18\x06 \x01(\x0b\x32=.org.couchers.api.discussions.ListMyCommunitiesDiscussionsRes2\x83\x01\n\tDashboard\x12p\n\x0eGetDashboardV2\x12-.org.couchers.api.dashboard.GetDashboardV2Req\x1a-.org.couchers.api.dashboard.GetDashboardV2Res\"\x00\x1a\x04\x88\xb5\x18\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dashboard_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_DASHBOARD']._loaded_options = None
  _globals['_DASHBOARD']._serialized_options = b'\210\265\030\003'
  _globals['_GETDASHBOARDV2REQ']._serialized_start=130
  _globals['_GETDASHBOARDV2REQ']._serialized_end=149
  _globals['_GETDASHBOARDV2RES']._serialized_start=152
  _globals['_GETDASHBOARDV2RES']._serialized_end=576
  _globals['_DASHBOARD']._serialized_start=579
  _globals['_DASHBOARD']._serialized_end=710
# @@protoc_insertion_point(module_scope)
