# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: auth.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from . import annotations_pb2 as annotations__pb2
from . import api_pb2 as api__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nauth.proto\x12\x11org.couchers.auth\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x11\x61nnotations.proto\x1a\tapi.proto\"\xfb\x02\n\rSignupFlowReq\x12\x18\n\nflow_token\x18\x01 \x01(\tB\x04\x88\xb5\x18\x01\x12-\n\x05\x62\x61sic\x18\x02 \x01(\x0b\x32\x1e.org.couchers.auth.SignupBasic\x12\x31\n\x07\x61\x63\x63ount\x18\x03 \x01(\x0b\x32 .org.couchers.auth.SignupAccount\x12\x34\n\x08\x66\x65\x65\x64\x62\x61\x63k\x18\x04 \x01(\x0b\x32\".org.couchers.auth.ContributorForm\x12\x39\n\x0bmotivations\x18\x08 \x01(\x0b\x32$.org.couchers.auth.SignupMotivations\x12\x19\n\x0b\x65mail_token\x18\x05 \x01(\tB\x04\x88\xb5\x18\x01\x12?\n\x1b\x61\x63\x63\x65pt_community_guidelines\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12!\n\x19resend_verification_email\x18\x07 \x01(\x08\"\xf7\x01\n\rSignupFlowRes\x12\x18\n\nflow_token\x18\x01 \x01(\tB\x04\x88\xb5\x18\x01\x12,\n\x08\x61uth_res\x18\x03 \x01(\x0b\x32\x1a.org.couchers.auth.AuthRes\x12\x12\n\nneed_basic\x18\x04 \x01(\x08\x12\x14\n\x0cneed_account\x18\x05 \x01(\x08\x12\x15\n\rneed_feedback\x18\x06 \x01(\x08\x12\x18\n\x10need_motivations\x18\t \x01(\x08\x12\x19\n\x11need_verify_email\x18\x07 \x01(\x08\x12(\n need_accept_community_guidelines\x18\x08 \x01(\x08\"?\n\x0bSignupBasic\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\x12\x13\n\x0binvite_code\x18\x03 \x01(\t\"0\n\x12SignupTokenInfoReq\x12\x1a\n\x0csignup_token\x18\x01 \x01(\tB\x04\x88\xb5\x18\x01\"\x85\x02\n\rSignupAccount\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x16\n\x08password\x18\x02 \x01(\tB\x04\x80\xb5\x18\x01\x12\x0c\n\x04\x63ity\x18\x06 \x01(\t\x12\x0b\n\x03lat\x18\x07 \x01(\x01\x12\x0b\n\x03lng\x18\x08 \x01(\x01\x12\x0e\n\x06radius\x18\t \x01(\x01\x12\x11\n\tbirthdate\x18\x03 \x01(\t\x12\x0e\n\x06gender\x18\x04 \x01(\t\x12<\n\x0ehosting_status\x18\x05 \x01(\x0e\x32$.org.couchers.api.core.HostingStatus\x12\x12\n\naccept_tos\x18\n \x01(\x08\x12\x1d\n\x15opt_out_of_newsletter\x18\x0b \x01(\x08\"F\n\x11SignupMotivations\x12\x1c\n\x14heard_about_couchers\x18\x01 \x01(\t\x12\x13\n\x0bmotivations\x18\x02 \x03(\t\"$\n\x10UsernameValidReq\x12\x10\n\x08username\x18\x01 \x01(\t\"!\n\x10UsernameValidRes\x12\r\n\x05valid\x18\x01 \x01(\x08\"H\n\x07\x41uthReq\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x16\n\x08password\x18\x02 \x01(\tB\x04\x80\xb5\x18\x01\x12\x17\n\x0fremember_device\x18\x03 \x01(\x08\"*\n\x07\x41uthRes\x12\x0f\n\x07user_id\x18\x01 \x01(\x03\x12\x0e\n\x06jailed\x18\x02 \x01(\x08\"R\n\x0fGetAuthStateRes\x12\x11\n\tlogged_in\x18\x01 \x01(\x08\x12,\n\x08\x61uth_res\x18\x02 \x01(\x0b\x32\x1a.org.couchers.auth.AuthRes\" \n\x10ResetPasswordReq\x12\x0c\n\x04user\x18\x01 \x01(\t\"\\\n\x1a\x43ompletePasswordResetV2Req\x12\"\n\x14password_reset_token\x18\x01 \x01(\tB\x04\x88\xb5\x18\x01\x12\x1a\n\x0cnew_password\x18\x02 \x01(\tB\x04\x80\xb5\x18\x01\";\n\x17\x43onfirmChangeEmailV2Req\x12 \n\x12\x63hange_email_token\x18\x01 \x01(\tB\x04\x88\xb5\x18\x01\"\xab\x01\n\x0f\x43ontributorForm\x12\r\n\x05ideas\x18\x01 \x01(\t\x12\x10\n\x08\x66\x65\x61tures\x18\x02 \x01(\t\x12\x12\n\nexperience\x18\x03 \x01(\t\x12\x37\n\ncontribute\x18\x04 \x01(\x0e\x32#.org.couchers.auth.ContributeOption\x12\x17\n\x0f\x63ontribute_ways\x18\x05 \x03(\t\x12\x11\n\texpertise\x18\x06 \x01(\t\".\n\x17\x43onfirmDeleteAccountReq\x12\x13\n\x05token\x18\x01 \x01(\tB\x04\x88\xb5\x18\x01\"(\n\x11RecoverAccountReq\x12\x13\n\x05token\x18\x01 \x01(\tB\x04\x88\xb5\x18\x01\".\n\x0eUnsubscribeReq\x12\x0f\n\x07payload\x18\x01 \x01(\x0c\x12\x0b\n\x03sig\x18\x02 \x01(\x0c\"\"\n\x0eUnsubscribeRes\x12\x10\n\x08response\x18\x01 \x01(\t\"+\n\nAntiBotReq\x12\r\n\x05token\x18\x01 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x02 \x01(\t\"\x0c\n\nAntiBotRes\"\x12\n\x10\x41ntiBotPolicyReq\"*\n\x10\x41ntiBotPolicyRes\x12\x16\n\x0eshould_antibot\x18\x01 \x01(\x08\"$\n\x14GetInviteCodeInfoReq\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\"W\n\x14GetInviteCodeInfoRes\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x12\n\navatar_url\x18\x03 \x01(\t\x12\x0b\n\x03url\x18\x04 \x01(\t*\x87\x01\n\x10\x43ontributeOption\x12!\n\x1d\x43ONTRIBUTE_OPTION_UNSPECIFIED\x10\x00\x12\x19\n\x15\x43ONTRIBUTE_OPTION_YES\x10\x01\x12\x1b\n\x17\x43ONTRIBUTE_OPTION_MAYBE\x10\x02\x12\x18\n\x14\x43ONTRIBUTE_OPTION_NO\x10\x03\x32\xc7\t\n\x04\x41uth\x12R\n\nSignupFlow\x12 .org.couchers.auth.SignupFlowReq\x1a .org.couchers.auth.SignupFlowRes\"\x00\x12[\n\rUsernameValid\x12#.org.couchers.auth.UsernameValidReq\x1a#.org.couchers.auth.UsernameValidRes\"\x00\x12H\n\x0c\x41uthenticate\x12\x1a.org.couchers.auth.AuthReq\x1a\x1a.org.couchers.auth.AuthRes\"\x00\x12L\n\x0cGetAuthState\x12\x16.google.protobuf.Empty\x1a\".org.couchers.auth.GetAuthStateRes\"\x00\x12\x42\n\x0e\x44\x65\x61uthenticate\x12\x16.google.protobuf.Empty\x1a\x16.google.protobuf.Empty\"\x00\x12N\n\rResetPassword\x12#.org.couchers.auth.ResetPasswordReq\x1a\x16.google.protobuf.Empty\"\x00\x12\x66\n\x17\x43ompletePasswordResetV2\x12-.org.couchers.auth.CompletePasswordResetV2Req\x1a\x1a.org.couchers.auth.AuthRes\"\x00\x12\\\n\x14\x43onfirmChangeEmailV2\x12*.org.couchers.auth.ConfirmChangeEmailV2Req\x1a\x16.google.protobuf.Empty\"\x00\x12\\\n\x14\x43onfirmDeleteAccount\x12*.org.couchers.auth.ConfirmDeleteAccountReq\x1a\x16.google.protobuf.Empty\"\x00\x12P\n\x0eRecoverAccount\x12$.org.couchers.auth.RecoverAccountReq\x1a\x16.google.protobuf.Empty\"\x00\x12U\n\x0bUnsubscribe\x12!.org.couchers.auth.UnsubscribeReq\x1a!.org.couchers.auth.UnsubscribeRes\"\x00\x12I\n\x07\x41ntiBot\x12\x1d.org.couchers.auth.AntiBotReq\x1a\x1d.org.couchers.auth.AntiBotRes\"\x00\x12[\n\rAntiBotPolicy\x12#.org.couchers.auth.AntiBotPolicyReq\x1a#.org.couchers.auth.AntiBotPolicyRes\"\x00\x12g\n\x11GetInviteCodeInfo\x12\'.org.couchers.auth.GetInviteCodeInfoReq\x1a\'.org.couchers.auth.GetInviteCodeInfoRes\"\x00\x1a\x04\x88\xb5\x18\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'auth_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_SIGNUPFLOWREQ'].fields_by_name['flow_token']._loaded_options = None
  _globals['_SIGNUPFLOWREQ'].fields_by_name['flow_token']._serialized_options = b'\210\265\030\001'
  _globals['_SIGNUPFLOWREQ'].fields_by_name['email_token']._loaded_options = None
  _globals['_SIGNUPFLOWREQ'].fields_by_name['email_token']._serialized_options = b'\210\265\030\001'
  _globals['_SIGNUPFLOWRES'].fields_by_name['flow_token']._loaded_options = None
  _globals['_SIGNUPFLOWRES'].fields_by_name['flow_token']._serialized_options = b'\210\265\030\001'
  _globals['_SIGNUPTOKENINFOREQ'].fields_by_name['signup_token']._loaded_options = None
  _globals['_SIGNUPTOKENINFOREQ'].fields_by_name['signup_token']._serialized_options = b'\210\265\030\001'
  _globals['_SIGNUPACCOUNT'].fields_by_name['password']._loaded_options = None
  _globals['_SIGNUPACCOUNT'].fields_by_name['password']._serialized_options = b'\200\265\030\001'
  _globals['_AUTHREQ'].fields_by_name['password']._loaded_options = None
  _globals['_AUTHREQ'].fields_by_name['password']._serialized_options = b'\200\265\030\001'
  _globals['_COMPLETEPASSWORDRESETV2REQ'].fields_by_name['password_reset_token']._loaded_options = None
  _globals['_COMPLETEPASSWORDRESETV2REQ'].fields_by_name['password_reset_token']._serialized_options = b'\210\265\030\001'
  _globals['_COMPLETEPASSWORDRESETV2REQ'].fields_by_name['new_password']._loaded_options = None
  _globals['_COMPLETEPASSWORDRESETV2REQ'].fields_by_name['new_password']._serialized_options = b'\200\265\030\001'
  _globals['_CONFIRMCHANGEEMAILV2REQ'].fields_by_name['change_email_token']._loaded_options = None
  _globals['_CONFIRMCHANGEEMAILV2REQ'].fields_by_name['change_email_token']._serialized_options = b'\210\265\030\001'
  _globals['_CONFIRMDELETEACCOUNTREQ'].fields_by_name['token']._loaded_options = None
  _globals['_CONFIRMDELETEACCOUNTREQ'].fields_by_name['token']._serialized_options = b'\210\265\030\001'
  _globals['_RECOVERACCOUNTREQ'].fields_by_name['token']._loaded_options = None
  _globals['_RECOVERACCOUNTREQ'].fields_by_name['token']._serialized_options = b'\210\265\030\001'
  _globals['_AUTH']._loaded_options = None
  _globals['_AUTH']._serialized_options = b'\210\265\030\001'
  _globals['_CONTRIBUTEOPTION']._serialized_start=2270
  _globals['_CONTRIBUTEOPTION']._serialized_end=2405
  _globals['_SIGNUPFLOWREQ']._serialized_start=125
  _globals['_SIGNUPFLOWREQ']._serialized_end=504
  _globals['_SIGNUPFLOWRES']._serialized_start=507
  _globals['_SIGNUPFLOWRES']._serialized_end=754
  _globals['_SIGNUPBASIC']._serialized_start=756
  _globals['_SIGNUPBASIC']._serialized_end=819
  _globals['_SIGNUPTOKENINFOREQ']._serialized_start=821
  _globals['_SIGNUPTOKENINFOREQ']._serialized_end=869
  _globals['_SIGNUPACCOUNT']._serialized_start=872
  _globals['_SIGNUPACCOUNT']._serialized_end=1133
  _globals['_SIGNUPMOTIVATIONS']._serialized_start=1135
  _globals['_SIGNUPMOTIVATIONS']._serialized_end=1205
  _globals['_USERNAMEVALIDREQ']._serialized_start=1207
  _globals['_USERNAMEVALIDREQ']._serialized_end=1243
  _globals['_USERNAMEVALIDRES']._serialized_start=1245
  _globals['_USERNAMEVALIDRES']._serialized_end=1278
  _globals['_AUTHREQ']._serialized_start=1280
  _globals['_AUTHREQ']._serialized_end=1352
  _globals['_AUTHRES']._serialized_start=1354
  _globals['_AUTHRES']._serialized_end=1396
  _globals['_GETAUTHSTATERES']._serialized_start=1398
  _globals['_GETAUTHSTATERES']._serialized_end=1480
  _globals['_RESETPASSWORDREQ']._serialized_start=1482
  _globals['_RESETPASSWORDREQ']._serialized_end=1514
  _globals['_COMPLETEPASSWORDRESETV2REQ']._serialized_start=1516
  _globals['_COMPLETEPASSWORDRESETV2REQ']._serialized_end=1608
  _globals['_CONFIRMCHANGEEMAILV2REQ']._serialized_start=1610
  _globals['_CONFIRMCHANGEEMAILV2REQ']._serialized_end=1669
  _globals['_CONTRIBUTORFORM']._serialized_start=1672
  _globals['_CONTRIBUTORFORM']._serialized_end=1843
  _globals['_CONFIRMDELETEACCOUNTREQ']._serialized_start=1845
  _globals['_CONFIRMDELETEACCOUNTREQ']._serialized_end=1891
  _globals['_RECOVERACCOUNTREQ']._serialized_start=1893
  _globals['_RECOVERACCOUNTREQ']._serialized_end=1933
  _globals['_UNSUBSCRIBEREQ']._serialized_start=1935
  _globals['_UNSUBSCRIBEREQ']._serialized_end=1981
  _globals['_UNSUBSCRIBERES']._serialized_start=1983
  _globals['_UNSUBSCRIBERES']._serialized_end=2017
  _globals['_ANTIBOTREQ']._serialized_start=2019
  _globals['_ANTIBOTREQ']._serialized_end=2062
  _globals['_ANTIBOTRES']._serialized_start=2064
  _globals['_ANTIBOTRES']._serialized_end=2076
  _globals['_ANTIBOTPOLICYREQ']._serialized_start=2078
  _globals['_ANTIBOTPOLICYREQ']._serialized_end=2096
  _globals['_ANTIBOTPOLICYRES']._serialized_start=2098
  _globals['_ANTIBOTPOLICYRES']._serialized_end=2140
  _globals['_GETINVITECODEINFOREQ']._serialized_start=2142
  _globals['_GETINVITECODEINFOREQ']._serialized_end=2178
  _globals['_GETINVITECODEINFORES']._serialized_start=2180
  _globals['_GETINVITECODEINFORES']._serialized_end=2267
  _globals['_AUTH']._serialized_start=2408
  _globals['_AUTH']._serialized_end=3631
# @@protoc_insertion_point(module_scope)
