from sqlalchemy import orm
from couchers.context import CouchersContext
"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import dashboard_pb2
import grpc
import grpc.aio
import typing


GRPC_GENERATED_VERSION: str
GRPC_VERSION: str

class DashboardStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    GetDashboardV2: grpc.UnaryUnaryMultiCallable[dashboard_pb2.GetDashboardV2Req, dashboard_pb2.GetDashboardV2Res]
    """Fetch all the content needed to render the dashboard in a single call, instead of fanning out
    to the individual RPCs. Each field mirrors the response of the RPC that previously populated it.
    """

class DashboardServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetDashboardV2(
        self,
        request: dashboard_pb2.GetDashboardV2Req,
        context: CouchersContext,
        session: orm.Session,
    ) -> dashboard_pb2.GetDashboardV2Res:
        """Fetch all the content needed to render the dashboard in a single call, instead of fanning out
        to the individual RPCs. Each field mirrors the response of the RPC that previously populated it.
        """

def add_DashboardServicer_to_server(servicer: DashboardServicer, server: grpc.Server) -> None: ...
