# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import moderation_pb2 as moderation__pb2


class ModerationStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetModerationQueue = channel.unary_unary(
                '/org.couchers.moderation.Moderation/GetModerationQueue',
                request_serializer=moderation__pb2.GetModerationQueueReq.SerializeToString,
                response_deserializer=moderation__pb2.GetModerationQueueRes.FromString,
                )
        self.GetModerationState = channel.unary_unary(
                '/org.couchers.moderation.Moderation/GetModerationState',
                request_serializer=moderation__pb2.GetModerationStateReq.SerializeToString,
                response_deserializer=moderation__pb2.GetModerationStateRes.FromString,
                )
        self.GetModerationLog = channel.unary_unary(
                '/org.couchers.moderation.Moderation/GetModerationLog',
                request_serializer=moderation__pb2.GetModerationLogReq.SerializeToString,
                response_deserializer=moderation__pb2.GetModerationLogRes.FromString,
                )
        self.ModerateContent = channel.unary_unary(
                '/org.couchers.moderation.Moderation/ModerateContent',
                request_serializer=moderation__pb2.ModerateContentReq.SerializeToString,
                response_deserializer=moderation__pb2.ModerateContentRes.FromString,
                )
        self.SetUserContentVisibility = channel.unary_unary(
                '/org.couchers.moderation.Moderation/SetUserContentVisibility',
                request_serializer=moderation__pb2.SetUserContentVisibilityReq.SerializeToString,
                response_deserializer=moderation__pb2.SetUserContentVisibilityRes.FromString,
                )
        self.ListModerationStates = channel.unary_unary(
                '/org.couchers.moderation.Moderation/ListModerationStates',
                request_serializer=moderation__pb2.ListModerationStatesReq.SerializeToString,
                response_deserializer=moderation__pb2.ListModerationStatesRes.FromString,
                )


class ModerationServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetModerationQueue(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetModerationState(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetModerationLog(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ModerateContent(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetUserContentVisibility(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListModerationStates(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ModerationServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetModerationQueue': grpc.unary_unary_rpc_method_handler(
                    servicer.GetModerationQueue,
                    request_deserializer=moderation__pb2.GetModerationQueueReq.FromString,
                    response_serializer=moderation__pb2.GetModerationQueueRes.SerializeToString,
            ),
            'GetModerationState': grpc.unary_unary_rpc_method_handler(
                    servicer.GetModerationState,
                    request_deserializer=moderation__pb2.GetModerationStateReq.FromString,
                    response_serializer=moderation__pb2.GetModerationStateRes.SerializeToString,
            ),
            'GetModerationLog': grpc.unary_unary_rpc_method_handler(
                    servicer.GetModerationLog,
                    request_deserializer=moderation__pb2.GetModerationLogReq.FromString,
                    response_serializer=moderation__pb2.GetModerationLogRes.SerializeToString,
            ),
            'ModerateContent': grpc.unary_unary_rpc_method_handler(
                    servicer.ModerateContent,
                    request_deserializer=moderation__pb2.ModerateContentReq.FromString,
                    response_serializer=moderation__pb2.ModerateContentRes.SerializeToString,
            ),
            'SetUserContentVisibility': grpc.unary_unary_rpc_method_handler(
                    servicer.SetUserContentVisibility,
                    request_deserializer=moderation__pb2.SetUserContentVisibilityReq.FromString,
                    response_serializer=moderation__pb2.SetUserContentVisibilityRes.SerializeToString,
            ),
            'ListModerationStates': grpc.unary_unary_rpc_method_handler(
                    servicer.ListModerationStates,
                    request_deserializer=moderation__pb2.ListModerationStatesReq.FromString,
                    response_serializer=moderation__pb2.ListModerationStatesRes.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'org.couchers.moderation.Moderation', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Moderation(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetModerationQueue(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.moderation.Moderation/GetModerationQueue',
            moderation__pb2.GetModerationQueueReq.SerializeToString,
            moderation__pb2.GetModerationQueueRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetModerationState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.moderation.Moderation/GetModerationState',
            moderation__pb2.GetModerationStateReq.SerializeToString,
            moderation__pb2.GetModerationStateRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetModerationLog(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.moderation.Moderation/GetModerationLog',
            moderation__pb2.GetModerationLogReq.SerializeToString,
            moderation__pb2.GetModerationLogRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ModerateContent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.moderation.Moderation/ModerateContent',
            moderation__pb2.ModerateContentReq.SerializeToString,
            moderation__pb2.ModerateContentRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetUserContentVisibility(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.moderation.Moderation/SetUserContentVisibility',
            moderation__pb2.SetUserContentVisibilityReq.SerializeToString,
            moderation__pb2.SetUserContentVisibilityRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListModerationStates(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.moderation.Moderation/ListModerationStates',
            moderation__pb2.ListModerationStatesReq.SerializeToString,
            moderation__pb2.ListModerationStatesRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
