# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: communities.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import annotations_pb2 as annotations__pb2
from . import discussions_pb2 as discussions__pb2
from . import events_pb2 as events__pb2
from . import groups_pb2 as groups__pb2
from . import pages_pb2 as pages__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x63ommunities.proto\x12\x1corg.couchers.api.communities\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x11\x61nnotations.proto\x1a\x11\x64iscussions.proto\x1a\x0c\x65vents.proto\x1a\x0cgroups.proto\x1a\x0bpages.proto\"\xd8\x03\n\tCommunity\x12\x14\n\x0c\x63ommunity_id\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04slug\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12+\n\x07\x63reated\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x07parents\x18\x06 \x03(\x0b\x32\x1f.org.couchers.api.groups.Parent\x12/\n\tmain_page\x18\x07 \x01(\x0b\x32\x1c.org.couchers.api.pages.Page\x12\x0e\n\x06member\x18\x08 \x01(\x08\x12\r\n\x05\x61\x64min\x18\t \x01(\x08\x12\x14\n\x0cmember_count\x18\n \x01(\r\x12\x13\n\x0b\x61\x64min_count\x18\x0b \x01(\r\x12\x19\n\x11nearby_user_count\x18\x0c \x01(\r\x12\x14\n\x0c\x63\x61n_moderate\x18\r \x01(\x08\x12(\n small_community_features_enabled\x18\x0e \x01(\x08\x12\x39\n\tnode_type\x18\x10 \x01(\x0e\x32&.org.couchers.api.communities.NodeTypeJ\x04\x08\x0f\x10\x10R\x0e\x65vents_enabled\"\'\n\x0fGetCommunityReq\x12\x14\n\x0c\x63ommunity_id\x18\x01 \x01(\x03\"Q\n\x12ListCommunitiesReq\x12\x14\n\x0c\x63ommunity_id\x18\x01 \x01(\x03\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"k\n\x12ListCommunitiesRes\x12<\n\x0b\x63ommunities\x18\x01 \x03(\x0b\x32\'.org.couchers.api.communities.Community\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"P\n\x16ListUserCommunitiesReq\x12\x0f\n\x07user_id\x18\x01 \x01(\r\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"o\n\x16ListUserCommunitiesRes\x12<\n\x0b\x63ommunities\x18\x01 \x03(\x0b\x32\'.org.couchers.api.communities.Community\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"L\n\rListGroupsReq\x12\x14\n\x0c\x63ommunity_id\x18\x01 \x01(\x03\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"X\n\rListGroupsRes\x12.\n\x06groups\x18\x01 \x03(\x0b\x32\x1e.org.couchers.api.groups.Group\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"L\n\rListAdminsReq\x12\x14\n\x0c\x63ommunity_id\x18\x01 \x01(\x03\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"@\n\rListAdminsRes\x12\x16\n\x0e\x61\x64min_user_ids\x18\x01 \x03(\x03\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"4\n\x0b\x41\x64\x64\x41\x64minReq\x12\x0f\n\x07user_id\x18\x01 \x01(\x03\x12\x14\n\x0c\x63ommunity_id\x18\x02 \x01(\x03\"7\n\x0eRemoveAdminReq\x12\x0f\n\x07user_id\x18\x01 \x01(\x03\x12\x14\n\x0c\x63ommunity_id\x18\x02 \x01(\x03\"M\n\x0eListMembersReq\x12\x14\n\x0c\x63ommunity_id\x18\x01 \x01(\x03\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"B\n\x0eListMembersRes\x12\x17\n\x0fmember_user_ids\x18\x01 \x03(\x03\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"Q\n\x12ListNearbyUsersReq\x12\x14\n\x0c\x63ommunity_id\x18\x01 \x01(\x03\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"F\n\x12ListNearbyUsersRes\x12\x17\n\x0fnearby_user_ids\x18\x01 \x03(\x03\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"L\n\rListPlacesReq\x12\x14\n\x0c\x63ommunity_id\x18\x01 \x01(\x03\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"V\n\rListPlacesRes\x12,\n\x06places\x18\x01 \x03(\x0b\x32\x1c.org.couchers.api.pages.Page\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"L\n\rListGuidesReq\x12\x14\n\x0c\x63ommunity_id\x18\x01 \x01(\x03\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"V\n\rListGuidesRes\x12,\n\x06guides\x18\x01 \x03(\x0b\x32\x1c.org.couchers.api.pages.Page\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"s\n\rListEventsReq\x12\x14\n\x0c\x63ommunity_id\x18\x01 \x01(\x03\x12\x0c\n\x04past\x18\x04 \x01(\x08\x12\x17\n\x0finclude_parents\x18\x05 \x01(\x08\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"X\n\rListEventsRes\x12.\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x1e.org.couchers.api.events.Event\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"Q\n\x12ListDiscussionsReq\x12\x14\n\x0c\x63ommunity_id\x18\x01 \x01(\x03\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"l\n\x12ListDiscussionsRes\x12=\n\x0b\x64iscussions\x18\x01 \x03(\x0b\x32(.org.couchers.api.discussions.Discussion\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"(\n\x10JoinCommunityReq\x12\x14\n\x0c\x63ommunity_id\x18\x01 \x01(\x03\")\n\x11LeaveCommunityReq\x12\x14\n\x0c\x63ommunity_id\x18\x01 \x01(\x03\"8\n\x14SearchCommunitiesReq\x12\r\n\x05query\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\r\"T\n\x14SearchCommunitiesRes\x12<\n\x0b\x63ommunities\x18\x01 \x03(\x0b\x32\'.org.couchers.api.communities.Community\"\x84\x02\n\x10\x43ommunitySummary\x12\x14\n\x0c\x63ommunity_id\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04slug\x18\x03 \x01(\t\x12\x0e\n\x06member\x18\x04 \x01(\x08\x12\x14\n\x0cmember_count\x18\x05 \x01(\r\x12\x30\n\x07parents\x18\x06 \x03(\x0b\x32\x1f.org.couchers.api.groups.Parent\x12+\n\x07\x63reated\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\tnode_type\x18\x08 \x01(\x0e\x32&.org.couchers.api.communities.NodeType\"\x17\n\x15ListAllCommunitiesReq\"\\\n\x15ListAllCommunitiesRes\x12\x43\n\x0b\x63ommunities\x18\x01 \x03(\x0b\x32..org.couchers.api.communities.CommunitySummary\"-\n\x18ListRecentCommunitiesReq\x12\x11\n\tpage_size\x18\x01 \x01(\r\"_\n\x18ListRecentCommunitiesRes\x12\x43\n\x0b\x63ommunities\x18\x01 \x03(\x0b\x32..org.couchers.api.communities.CommunitySummary*\xb7\x01\n\x08NodeType\x12\x19\n\x15NODE_TYPE_UNSPECIFIED\x10\x00\x12\x13\n\x0fNODE_TYPE_WORLD\x10\x01\x12\x19\n\x15NODE_TYPE_MACROREGION\x10\x02\x12\x14\n\x10NODE_TYPE_REGION\x10\x03\x12\x17\n\x13NODE_TYPE_SUBREGION\x10\x04\x12\x16\n\x12NODE_TYPE_LOCALITY\x10\x05\x12\x19\n\x15NODE_TYPE_SUBLOCALITY\x10\x06\x32\xdb\x0f\n\x0b\x43ommunities\x12h\n\x0cGetCommunity\x12-.org.couchers.api.communities.GetCommunityReq\x1a\'.org.couchers.api.communities.Community\"\x00\x12w\n\x0fListCommunities\x12\x30.org.couchers.api.communities.ListCommunitiesReq\x1a\x30.org.couchers.api.communities.ListCommunitiesRes\"\x00\x12h\n\nListGroups\x12+.org.couchers.api.communities.ListGroupsReq\x1a+.org.couchers.api.communities.ListGroupsRes\"\x00\x12h\n\nListAdmins\x12+.org.couchers.api.communities.ListAdminsReq\x1a+.org.couchers.api.communities.ListAdminsRes\"\x00\x12O\n\x08\x41\x64\x64\x41\x64min\x12).org.couchers.api.communities.AddAdminReq\x1a\x16.google.protobuf.Empty\"\x00\x12U\n\x0bRemoveAdmin\x12,.org.couchers.api.communities.RemoveAdminReq\x1a\x16.google.protobuf.Empty\"\x00\x12k\n\x0bListMembers\x12,.org.couchers.api.communities.ListMembersReq\x1a,.org.couchers.api.communities.ListMembersRes\"\x00\x12w\n\x0fListNearbyUsers\x12\x30.org.couchers.api.communities.ListNearbyUsersReq\x1a\x30.org.couchers.api.communities.ListNearbyUsersRes\"\x00\x12h\n\nListPlaces\x12+.org.couchers.api.communities.ListPlacesReq\x1a+.org.couchers.api.communities.ListPlacesRes\"\x00\x12h\n\nListGuides\x12+.org.couchers.api.communities.ListGuidesReq\x1a+.org.couchers.api.communities.ListGuidesRes\"\x00\x12h\n\nListEvents\x12+.org.couchers.api.communities.ListEventsReq\x1a+.org.couchers.api.communities.ListEventsRes\"\x00\x12w\n\x0fListDiscussions\x12\x30.org.couchers.api.communities.ListDiscussionsReq\x1a\x30.org.couchers.api.communities.ListDiscussionsRes\"\x00\x12Y\n\rJoinCommunity\x12..org.couchers.api.communities.JoinCommunityReq\x1a\x16.google.protobuf.Empty\"\x00\x12[\n\x0eLeaveCommunity\x12/.org.couchers.api.communities.LeaveCommunityReq\x1a\x16.google.protobuf.Empty\"\x00\x12\x83\x01\n\x13ListUserCommunities\x12\x34.org.couchers.api.communities.ListUserCommunitiesReq\x1a\x34.org.couchers.api.communities.ListUserCommunitiesRes\"\x00\x12}\n\x11SearchCommunities\x12\x32.org.couchers.api.communities.SearchCommunitiesReq\x1a\x32.org.couchers.api.communities.SearchCommunitiesRes\"\x00\x12\x80\x01\n\x12ListAllCommunities\x12\x33.org.couchers.api.communities.ListAllCommunitiesReq\x1a\x33.org.couchers.api.communities.ListAllCommunitiesRes\"\x00\x12\x89\x01\n\x15ListRecentCommunities\x12\x36.org.couchers.api.communities.ListRecentCommunitiesReq\x1a\x36.org.couchers.api.communities.ListRecentCommunitiesRes\"\x00\x1a\x04\x88\xb5\x18\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'communities_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_COMMUNITIES']._loaded_options = None
  _globals['_COMMUNITIES']._serialized_options = b'\210\265\030\003'
  _globals['_NODETYPE']._serialized_start=3308
  _globals['_NODETYPE']._serialized_end=3491
  _globals['_COMMUNITY']._serialized_start=193
  _globals['_COMMUNITY']._serialized_end=665
  _globals['_GETCOMMUNITYREQ']._serialized_start=667
  _globals['_GETCOMMUNITYREQ']._serialized_end=706
  _globals['_LISTCOMMUNITIESREQ']._serialized_start=708
  _globals['_LISTCOMMUNITIESREQ']._serialized_end=789
  _globals['_LISTCOMMUNITIESRES']._serialized_start=791
  _globals['_LISTCOMMUNITIESRES']._serialized_end=898
  _globals['_LISTUSERCOMMUNITIESREQ']._serialized_start=900
  _globals['_LISTUSERCOMMUNITIESREQ']._serialized_end=980
  _globals['_LISTUSERCOMMUNITIESRES']._serialized_start=982
  _globals['_LISTUSERCOMMUNITIESRES']._serialized_end=1093
  _globals['_LISTGROUPSREQ']._serialized_start=1095
  _globals['_LISTGROUPSREQ']._serialized_end=1171
  _globals['_LISTGROUPSRES']._serialized_start=1173
  _globals['_LISTGROUPSRES']._serialized_end=1261
  _globals['_LISTADMINSREQ']._serialized_start=1263
  _globals['_LISTADMINSREQ']._serialized_end=1339
  _globals['_LISTADMINSRES']._serialized_start=1341
  _globals['_LISTADMINSRES']._serialized_end=1405
  _globals['_ADDADMINREQ']._serialized_start=1407
  _globals['_ADDADMINREQ']._serialized_end=1459
  _globals['_REMOVEADMINREQ']._serialized_start=1461
  _globals['_REMOVEADMINREQ']._serialized_end=1516
  _globals['_LISTMEMBERSREQ']._serialized_start=1518
  _globals['_LISTMEMBERSREQ']._serialized_end=1595
  _globals['_LISTMEMBERSRES']._serialized_start=1597
  _globals['_LISTMEMBERSRES']._serialized_end=1663
  _globals['_LISTNEARBYUSERSREQ']._serialized_start=1665
  _globals['_LISTNEARBYUSERSREQ']._serialized_end=1746
  _globals['_LISTNEARBYUSERSRES']._serialized_start=1748
  _globals['_LISTNEARBYUSERSRES']._serialized_end=1818
  _globals['_LISTPLACESREQ']._serialized_start=1820
  _globals['_LISTPLACESREQ']._serialized_end=1896
  _globals['_LISTPLACESRES']._serialized_start=1898
  _globals['_LISTPLACESRES']._serialized_end=1984
  _globals['_LISTGUIDESREQ']._serialized_start=1986
  _globals['_LISTGUIDESREQ']._serialized_end=2062
  _globals['_LISTGUIDESRES']._serialized_start=2064
  _globals['_LISTGUIDESRES']._serialized_end=2150
  _globals['_LISTEVENTSREQ']._serialized_start=2152
  _globals['_LISTEVENTSREQ']._serialized_end=2267
  _globals['_LISTEVENTSRES']._serialized_start=2269
  _globals['_LISTEVENTSRES']._serialized_end=2357
  _globals['_LISTDISCUSSIONSREQ']._serialized_start=2359
  _globals['_LISTDISCUSSIONSREQ']._serialized_end=2440
  _globals['_LISTDISCUSSIONSRES']._serialized_start=2442
  _globals['_LISTDISCUSSIONSRES']._serialized_end=2550
  _globals['_JOINCOMMUNITYREQ']._serialized_start=2552
  _globals['_JOINCOMMUNITYREQ']._serialized_end=2592
  _globals['_LEAVECOMMUNITYREQ']._serialized_start=2594
  _globals['_LEAVECOMMUNITYREQ']._serialized_end=2635
  _globals['_SEARCHCOMMUNITIESREQ']._serialized_start=2637
  _globals['_SEARCHCOMMUNITIESREQ']._serialized_end=2693
  _globals['_SEARCHCOMMUNITIESRES']._serialized_start=2695
  _globals['_SEARCHCOMMUNITIESRES']._serialized_end=2779
  _globals['_COMMUNITYSUMMARY']._serialized_start=2782
  _globals['_COMMUNITYSUMMARY']._serialized_end=3042
  _globals['_LISTALLCOMMUNITIESREQ']._serialized_start=3044
  _globals['_LISTALLCOMMUNITIESREQ']._serialized_end=3067
  _globals['_LISTALLCOMMUNITIESRES']._serialized_start=3069
  _globals['_LISTALLCOMMUNITIESRES']._serialized_end=3161
  _globals['_LISTRECENTCOMMUNITIESREQ']._serialized_start=3163
  _globals['_LISTRECENTCOMMUNITIESREQ']._serialized_end=3208
  _globals['_LISTRECENTCOMMUNITIESRES']._serialized_start=3210
  _globals['_LISTRECENTCOMMUNITIESRES']._serialized_end=3305
  _globals['_COMMUNITIES']._serialized_start=3494
  _globals['_COMMUNITIES']._serialized_end=5505
# @@protoc_insertion_point(module_scope)
