"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class InitiateDonationReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AMOUNT_FIELD_NUMBER: builtins.int
    RECURRING_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    amount: builtins.int
    """amount in USD, integral for now"""
    recurring: builtins.bool
    """whether to create a monthly recurring donation"""
    source: builtins.str
    """source of the donation (e.g., "strong-verification-complete")"""
    def __init__(
        self,
        *,
        amount: builtins.int | None = ...,
        recurring: builtins.bool | None = ...,
        source: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["amount", b"amount", "recurring", b"recurring", "source", b"source"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___InitiateDonationReq: typing_extensions.TypeAlias = InitiateDonationReq

@typing.final
class InitiateDonationRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STRIPE_CHECKOUT_SESSION_ID_FIELD_NUMBER: builtins.int
    STRIPE_CHECKOUT_URL_FIELD_NUMBER: builtins.int
    stripe_checkout_session_id: builtins.str
    stripe_checkout_url: builtins.str
    def __init__(
        self,
        *,
        stripe_checkout_session_id: builtins.str | None = ...,
        stripe_checkout_url: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["stripe_checkout_session_id", b"stripe_checkout_session_id", "stripe_checkout_url", b"stripe_checkout_url"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___InitiateDonationRes: typing_extensions.TypeAlias = InitiateDonationRes

@typing.final
class GetDonationPortalLinkRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STRIPE_PORTAL_URL_FIELD_NUMBER: builtins.int
    stripe_portal_url: builtins.str
    def __init__(
        self,
        *,
        stripe_portal_url: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["stripe_portal_url", b"stripe_portal_url"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___GetDonationPortalLinkRes: typing_extensions.TypeAlias = GetDonationPortalLinkRes
