# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: public.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from .google.api import httpbody_pb2 as google_dot_api_dot_httpbody__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import annotations_pb2 as annotations__pb2
from . import api_pb2 as api__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cpublic.proto\x12\x13org.couchers.public\x1a\x1cgoogle/api/annotations.proto\x1a\x19google/api/httpbody.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x11\x61nnotations.proto\x1a\tapi.proto\" \n\x10GetPublicUserReq\x12\x0c\n\x04user\x18\x01 \x01(\t\"\x9b\x02\n\x0bLimitedUser\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63ity\x18\x03 \x01(\t\x12\x10\n\x08hometown\x18\x04 \x01(\t\x12\x16\n\x0enum_references\x18\x05 \x01(\r\x12*\n\x06joined\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12<\n\x0ehosting_status\x18\x07 \x01(\x0e\x32$.org.couchers.api.core.HostingStatus\x12:\n\rmeetup_status\x18\x08 \x01(\x0e\x32#.org.couchers.api.core.MeetupStatus\x12\x0e\n\x06\x62\x61\x64ges\x18\t \x03(\t\"\x80\x05\n\x08MostUser\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63ity\x18\x03 \x01(\t\x12\x10\n\x08hometown\x18\x04 \x01(\t\x12\x10\n\x08timezone\x18\x05 \x01(\t\x12\x16\n\x0enum_references\x18\x06 \x01(\r\x12\x0e\n\x06gender\x18\x07 \x01(\t\x12\x10\n\x08pronouns\x18\x08 \x01(\t\x12\x0b\n\x03\x61ge\x18\t \x01(\r\x12*\n\x06joined\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0blast_active\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12<\n\x0ehosting_status\x18\x0c \x01(\x0e\x32$.org.couchers.api.core.HostingStatus\x12:\n\rmeetup_status\x18\r \x01(\x0e\x32#.org.couchers.api.core.MeetupStatus\x12\x12\n\noccupation\x18\x0e \x01(\t\x12\x11\n\teducation\x18\x0f \x01(\t\x12\x10\n\x08\x61\x62out_me\x18\x10 \x01(\t\x12\x15\n\rthings_i_like\x18\x11 \x01(\t\x12\x17\n\x0fregions_visited\x18\x12 \x03(\t\x12\x15\n\rregions_lived\x18\x13 \x03(\t\x12\x12\n\navatar_url\x18\x14 \x01(\t\x12\x1c\n\x14\x61vatar_thumbnail_url\x18\x15 \x01(\t\x12\x42\n\x12language_abilities\x18\x16 \x03(\x0b\x32&.org.couchers.api.core.LanguageAbility\x12\x0e\n\x06\x62\x61\x64ges\x18\x17 \x03(\t\"\xbd\x01\n\x10GetPublicUserRes\x12\x38\n\x0climited_user\x18\x01 \x01(\x0b\x32 .org.couchers.public.LimitedUserH\x00\x12\x32\n\tmost_user\x18\x02 \x01(\x0b\x32\x1d.org.couchers.public.MostUserH\x00\x12\x30\n\tfull_user\x18\x03 \x01(\x0b\x32\x1b.org.couchers.api.core.UserH\x00\x42\t\n\x07profile\"r\n\x14GetSignupPageInfoRes\x12/\n\x0blast_signup\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x15\n\rlast_location\x18\x02 \x01(\t\x12\x12\n\nuser_count\x18\x03 \x01(\x04\"\xa9\x01\n\tVolunteer\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x17\n\x0fis_board_member\x18\x03 \x01(\x08\x12\x0c\n\x04role\x18\x04 \x01(\t\x12\x10\n\x08location\x18\x05 \x01(\t\x12\x0b\n\x03img\x18\x06 \x01(\t\x12\x11\n\tlink_type\x18\x07 \x01(\t\x12\x11\n\tlink_text\x18\x08 \x01(\t\x12\x10\n\x08link_url\x18\t \x01(\t\"\x87\x01\n\x10GetVolunteersRes\x12:\n\x12\x63urrent_volunteers\x18\x01 \x03(\x0b\x32\x1e.org.couchers.public.Volunteer\x12\x37\n\x0fpast_volunteers\x18\x02 \x03(\x0b\x32\x1e.org.couchers.public.Volunteer\">\n\x13GetDonationStatsRes\x12\x19\n\x11total_donated_ytd\x18\x01 \x01(\x04\x12\x0c\n\x04goal\x18\x02 \x01(\x04\x32\xae\x04\n\x06Public\x12]\n\x0eGetPublicUsers\x12\x16.google.protobuf.Empty\x1a\x14.google.api.HttpBody\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/geojson/public-users\x12_\n\rGetPublicUser\x12%.org.couchers.public.GetPublicUserReq\x1a%.org.couchers.public.GetPublicUserRes\"\x00\x12x\n\x11GetSignupPageInfo\x12\x16.google.protobuf.Empty\x1a).org.couchers.public.GetSignupPageInfoRes\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/public/signup-page-info\x12n\n\rGetVolunteers\x12\x16.google.protobuf.Empty\x1a%.org.couchers.public.GetVolunteersRes\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/public/volunteer-info\x12t\n\x10GetDonationStats\x12\x16.google.protobuf.Empty\x1a(.org.couchers.public.GetDonationStatsRes\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/public/donation-stats\x1a\x04\x88\xb5\x18\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'public_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_PUBLIC']._loaded_options = None
  _globals['_PUBLIC']._serialized_options = b'\210\265\030\001'
  _globals['_PUBLIC'].methods_by_name['GetPublicUsers']._loaded_options = None
  _globals['_PUBLIC'].methods_by_name['GetPublicUsers']._serialized_options = b'\202\323\344\223\002\027\022\025/geojson/public-users'
  _globals['_PUBLIC'].methods_by_name['GetSignupPageInfo']._loaded_options = None
  _globals['_PUBLIC'].methods_by_name['GetSignupPageInfo']._serialized_options = b'\202\323\344\223\002\032\022\030/public/signup-page-info'
  _globals['_PUBLIC'].methods_by_name['GetVolunteers']._loaded_options = None
  _globals['_PUBLIC'].methods_by_name['GetVolunteers']._serialized_options = b'\202\323\344\223\002\030\022\026/public/volunteer-info'
  _globals['_PUBLIC'].methods_by_name['GetDonationStats']._loaded_options = None
  _globals['_PUBLIC'].methods_by_name['GetDonationStats']._serialized_options = b'\202\323\344\223\002\030\022\026/public/donation-stats'
  _globals['_GETPUBLICUSERREQ']._serialized_start=186
  _globals['_GETPUBLICUSERREQ']._serialized_end=218
  _globals['_LIMITEDUSER']._serialized_start=221
  _globals['_LIMITEDUSER']._serialized_end=504
  _globals['_MOSTUSER']._serialized_start=507
  _globals['_MOSTUSER']._serialized_end=1147
  _globals['_GETPUBLICUSERRES']._serialized_start=1150
  _globals['_GETPUBLICUSERRES']._serialized_end=1339
  _globals['_GETSIGNUPPAGEINFORES']._serialized_start=1341
  _globals['_GETSIGNUPPAGEINFORES']._serialized_end=1455
  _globals['_VOLUNTEER']._serialized_start=1458
  _globals['_VOLUNTEER']._serialized_end=1627
  _globals['_GETVOLUNTEERSRES']._serialized_start=1630
  _globals['_GETVOLUNTEERSRES']._serialized_end=1765
  _globals['_GETDONATIONSTATSRES']._serialized_start=1767
  _globals['_GETDONATIONSTATSRES']._serialized_end=1829
  _globals['_PUBLIC']._serialized_start=1832
  _globals['_PUBLIC']._serialized_end=2390
# @@protoc_insertion_point(module_scope)
