from sqlalchemy import orm
from couchers.context import CouchersContext
"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import google.protobuf.empty_pb2
import grpc
import grpc.aio
import notifications_pb2
import typing


GRPC_GENERATED_VERSION: str
GRPC_VERSION: str

class NotificationsStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    GetNotificationSettings: grpc.UnaryUnaryMultiCallable[notifications_pb2.GetNotificationSettingsReq, notifications_pb2.GetNotificationSettingsRes]
    SetNotificationSettings: grpc.UnaryUnaryMultiCallable[notifications_pb2.SetNotificationSettingsReq, notifications_pb2.GetNotificationSettingsRes]
    ListNotifications: grpc.UnaryUnaryMultiCallable[notifications_pb2.ListNotificationsReq, notifications_pb2.ListNotificationsRes]
    MarkNotificationSeen: grpc.UnaryUnaryMultiCallable[notifications_pb2.MarkNotificationSeenReq, google.protobuf.empty_pb2.Empty]
    MarkAllNotificationsSeen: grpc.UnaryUnaryMultiCallable[notifications_pb2.MarkAllNotificationsSeenReq, google.protobuf.empty_pb2.Empty]
    GetVapidPublicKey: grpc.UnaryUnaryMultiCallable[google.protobuf.empty_pb2.Empty, notifications_pb2.GetVapidPublicKeyRes]
    RegisterPushNotificationSubscription: grpc.UnaryUnaryMultiCallable[notifications_pb2.RegisterPushNotificationSubscriptionReq, google.protobuf.empty_pb2.Empty]
    SendTestPushNotification: grpc.UnaryUnaryMultiCallable[google.protobuf.empty_pb2.Empty, google.protobuf.empty_pb2.Empty]
    RegisterMobilePushNotificationSubscription: grpc.UnaryUnaryMultiCallable[notifications_pb2.RegisterMobilePushNotificationSubscriptionReq, google.protobuf.empty_pb2.Empty]
    SendTestMobilePushNotification: grpc.UnaryUnaryMultiCallable[google.protobuf.empty_pb2.Empty, google.protobuf.empty_pb2.Empty]
    SendDevPushNotification: grpc.UnaryUnaryMultiCallable[notifications_pb2.SendDevPushNotificationReq, google.protobuf.empty_pb2.Empty]
    """Development API: Send an arbitrary push notification to the current user.
    Gated behind ENABLE_DEV_APIS config.
    """
    DebugRedeliverPushNotification: grpc.UnaryUnaryMultiCallable[notifications_pb2.DebugRedeliverPushNotificationReq, google.protobuf.empty_pb2.Empty]
    """Debug API: Redeliver a push notification by notification_id.
    Gated behind ENABLE_DEV_APIS config.
    """

class NotificationsServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetNotificationSettings(
        self,
        request: notifications_pb2.GetNotificationSettingsReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> notifications_pb2.GetNotificationSettingsRes: ...

    @abc.abstractmethod
    def SetNotificationSettings(
        self,
        request: notifications_pb2.SetNotificationSettingsReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> notifications_pb2.GetNotificationSettingsRes: ...

    @abc.abstractmethod
    def ListNotifications(
        self,
        request: notifications_pb2.ListNotificationsReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> notifications_pb2.ListNotificationsRes: ...

    @abc.abstractmethod
    def MarkNotificationSeen(
        self,
        request: notifications_pb2.MarkNotificationSeenReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.protobuf.empty_pb2.Empty: ...

    @abc.abstractmethod
    def MarkAllNotificationsSeen(
        self,
        request: notifications_pb2.MarkAllNotificationsSeenReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.protobuf.empty_pb2.Empty: ...

    @abc.abstractmethod
    def GetVapidPublicKey(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> notifications_pb2.GetVapidPublicKeyRes: ...

    @abc.abstractmethod
    def RegisterPushNotificationSubscription(
        self,
        request: notifications_pb2.RegisterPushNotificationSubscriptionReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.protobuf.empty_pb2.Empty: ...

    @abc.abstractmethod
    def SendTestPushNotification(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.protobuf.empty_pb2.Empty: ...

    @abc.abstractmethod
    def RegisterMobilePushNotificationSubscription(
        self,
        request: notifications_pb2.RegisterMobilePushNotificationSubscriptionReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.protobuf.empty_pb2.Empty: ...

    @abc.abstractmethod
    def SendTestMobilePushNotification(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.protobuf.empty_pb2.Empty: ...

    @abc.abstractmethod
    def SendDevPushNotification(
        self,
        request: notifications_pb2.SendDevPushNotificationReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.protobuf.empty_pb2.Empty:
        """Development API: Send an arbitrary push notification to the current user.
        Gated behind ENABLE_DEV_APIS config.
        """

    @abc.abstractmethod
    def DebugRedeliverPushNotification(
        self,
        request: notifications_pb2.DebugRedeliverPushNotificationReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.protobuf.empty_pb2.Empty:
        """Debug API: Redeliver a push notification by notification_id.
        Gated behind ENABLE_DEV_APIS config.
        """

def add_NotificationsServicer_to_server(servicer: NotificationsServicer, server: grpc.Server) -> None: ...
