# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bugs.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from .google.api import httpbody_pb2 as google_dot_api_dot_httpbody__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import annotations_pb2 as annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nbugs.proto\x12\x11org.couchers.bugs\x1a\x1cgoogle/api/annotations.proto\x1a\x19google/api/httpbody.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x11\x61nnotations.proto\"\x1e\n\x0bVersionInfo\x12\x0f\n\x07version\x18\x01 \x01(\t\"1\n\x10ScreenResolution\x12\r\n\x05width\x18\x01 \x01(\x05\x12\x0e\n\x06height\x18\x02 \x01(\x05\"\xc1\x01\n\x0cReportBugReq\x12\x0f\n\x07subject\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0f\n\x07results\x18\x04 \x01(\t\x12\x18\n\x10\x66rontend_version\x18\x05 \x01(\t\x12\x12\n\nuser_agent\x18\x06 \x01(\t\x12\x0c\n\x04page\x18\x07 \x01(\t\x12>\n\x11screen_resolution\x18\x08 \x01(\x0b\x32#.org.couchers.bugs.ScreenResolution\"/\n\x0cReportBugRes\x12\x0e\n\x06\x62ug_id\x18\x02 \x01(\t\x12\x0f\n\x07\x62ug_url\x18\x03 \x01(\t\"\x1a\n\tStatusReq\x12\r\n\x05nonce\x18\x01 \x01(\t\"R\n\tStatusRes\x12\r\n\x05nonce\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x15\n\rcoucher_count\x18\x03 \x01(\x04\x12\x0e\n\x06stable\x18\x04 \x01(\x08\"\x84\x01\n\x18GeolocationSearchInfoReq\x12\x15\n\rsearch_string\x18\x01 \x01(\t\x12\x1d\n\x15nominatim_result_json\x18\x02 \x01(\t\x12\x1d\n\x15\x66ormatted_result_json\x18\x03 \x01(\t\x12\x13\n\x0b\x64uration_ms\x18\x04 \x01(\r\"e\n\x17GeolocationClickInfoReq\x12\x0f\n\x07\x63ontext\x18\x01 \x01(\t\x12\x1d\n\x15\x66ormatted_result_json\x18\x02 \x01(\t\x12\x1a\n\x12search_choice_json\x18\x03 \x01(\t\"s\n\x0e\x44iagnosticInfo\x12\x0b\n\x03tag\x18\x01 \x01(\t\x12\x17\n\x0fproperties_json\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\x01\x12,\n\x08occurred\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"b\n\x14ReportDiagnosticsReq\x12\x18\n\x10\x66rontend_version\x18\x01 \x01(\t\x12\x30\n\x05infos\x18\x02 \x03(\x0b\x32!.org.couchers.bugs.DiagnosticInfo\"\xaa\x06\n\x14\x43heckNativeStatusReq\x12\x12\n\ndebug_json\x18\x01 \x01(\t\x12\x15\n\reas_client_id\x18\x02 \x01(\t\x12\x12\n\ninstall_id\x18\x03 \x01(\t\x12\x11\n\tsticky_id\x18\x04 \x01(\t\x12\x0c\n\x04idfv\x18\x05 \x01(\t\x12\x12\n\nandroid_id\x18\x06 \x01(\t\x12\x13\n\x0b\x64\x65vice_name\x18\x07 \x01(\t\x12\x10\n\x08platform\x18\x08 \x01(\t\x12\x12\n\nos_version\x18\t \x01(\t\x12\x0e\n\x06locale\x18\n \x01(\t\x12\x12\n\nuser_state\x18\x0b \x01(\t\x12\x13\n\x0b\x61pp_variant\x18\x0c \x01(\t\x12\x13\n\x0b\x61pp_version\x18\r \x01(\t\x12\x14\n\x0cnative_build\x18\x0e \x01(\t\x12 \n\x18\x65mbedded_display_version\x18\x0f \x01(\t\x12\x1e\n\x16\x65mbedded_debug_version\x18\x10 \x01(\t\x12\x1f\n\x17running_display_version\x18\x11 \x01(\t\x12\x1d\n\x15running_debug_version\x18\x12 \x01(\t\x12!\n\x19running_debug_version_ota\x18\x13 \x01(\t\x12\x17\n\x0fruntime_version\x18\x14 \x01(\t\x12\x11\n\tupdate_id\x18\x15 \x01(\t\x12\x1a\n\x12is_embedded_launch\x18\x16 \x01(\x08\x12\x15\n\rlaunch_source\x18\x17 \x01(\t\x12\x37\n\x13\x65mbedded_created_at\x18\x18 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\ncreated_at\x18\x19 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x17\n\x0fpush_permission\x18\x1a \x01(\t\x12\x12\n\npush_token\x18\x1b \x01(\t\x12\x37\n\x14time_since_last_open\x18\x1c \x01(\x0b\x32\x19.google.protobuf.Duration\x12,\n\x08occurred\x18\x1d \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xa3\x02\n\x10NativeUpdateInfo\x12\x35\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32%.org.couchers.bugs.NativeUpdateAction\x12\x10\n\x08required\x18\x02 \x01(\x08\x12*\n\x06\x61\x63t_by\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0cnag_interval\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x0f\n\x07message\x18\x05 \x01(\t\x12\x10\n\x08link_url\x18\x06 \x01(\t\x12\x11\n\tlink_text\x18\x07 \x01(\t\x12\x33\n\x05\x63\x61use\x18\x08 \x01(\x0e\x32$.org.couchers.bugs.NativeUpdateCause\"P\n\x14\x43heckNativeStatusRes\x12\x38\n\x0bupdate_info\x18\x01 \x01(\x0b\x32#.org.couchers.bugs.NativeUpdateInfo\"*\n\x16\x45valuateFeatureFlagReq\x12\x10\n\x08\x66lag_key\x18\x01 \x01(\t\"?\n\x16\x45valuateFeatureFlagRes\x12%\n\x05value\x18\x01 \x01(\x0b\x32\x16.google.protobuf.Value\"\xe5\x02\n\x18LogExperimentExposureReq\x12\x16\n\x0e\x65xperiment_key\x18\x01 \x01(\t\x12\x17\n\x0f\x65xperiment_name\x18\x02 \x01(\t\x12\x14\n\x0cvariation_id\x18\x03 \x01(\x05\x12\x15\n\rvariation_key\x18\x04 \x01(\t\x12\x16\n\x0evariation_name\x18\x05 \x01(\t\x12\x16\n\x0ehash_attribute\x18\x06 \x01(\t\x12\x12\n\nhash_value\x18\x07 \x01(\t\x12\x12\n\nfeature_id\x18\x08 \x01(\t\x12\x15\n\rin_experiment\x18\t \x01(\x08\x12\x13\n\x06\x62ucket\x18\n \x01(\x01H\x00\x88\x01\x01\x12\x16\n\thash_used\x18\x0b \x01(\x08H\x01\x88\x01\x01\x12\x1f\n\x12sticky_bucket_used\x18\x0c \x01(\x08H\x02\x88\x01\x01\x42\t\n\x07_bucketB\x0c\n\n_hash_usedB\x15\n\x13_sticky_bucket_used*\xbb\x01\n\x12NativeUpdateAction\x12$\n NATIVE_UPDATE_ACTION_UNSPECIFIED\x10\x00\x12\x1d\n\x19NATIVE_UPDATE_ACTION_NONE\x10\x01\x12\x1c\n\x18NATIVE_UPDATE_ACTION_OTA\x10\x02\x12\x1e\n\x1aNATIVE_UPDATE_ACTION_STORE\x10\x03\x12\"\n\x1eNATIVE_UPDATE_ACTION_REINSTALL\x10\x04*u\n\x11NativeUpdateCause\x12#\n\x1fNATIVE_UPDATE_CAUSE_UNSPECIFIED\x10\x00\x12\x1b\n\x17NATIVE_UPDATE_CAUSE_AGE\x10\x01\x12\x1e\n\x1aNATIVE_UPDATE_CAUSE_BANNED\x10\x02\x32\x95\x08\n\x04\x42ugs\x12S\n\x07Version\x12\x16.google.protobuf.Empty\x1a\x1e.org.couchers.bugs.VersionInfo\"\x10\x82\xd3\xe4\x93\x02\n\x12\x08/version\x12O\n\tReportBug\x12\x1f.org.couchers.bugs.ReportBugReq\x1a\x1f.org.couchers.bugs.ReportBugRes\"\x00\x12U\n\x06Status\x12\x1c.org.couchers.bugs.StatusReq\x1a\x1c.org.couchers.bugs.StatusRes\"\x0f\x82\xd3\xe4\x93\x02\t\x12\x07/status\x12W\n\x0eGetDescriptors\x12\x16.google.protobuf.Empty\x1a\x14.google.api.HttpBody\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/descriptors.pb\x12\x63\n\x17GetNativeUpdateManifest\x12\x14.google.api.HttpBody\x1a\x14.google.api.HttpBody\"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14/native/ota/manifest\x12^\n\x15GeolocationSearchInfo\x12+.org.couchers.bugs.GeolocationSearchInfoReq\x1a\x16.google.protobuf.Empty\"\x00\x12\\\n\x14GeolocationClickInfo\x12*.org.couchers.bugs.GeolocationClickInfoReq\x1a\x16.google.protobuf.Empty\"\x00\x12V\n\x11ReportDiagnostics\x12\'.org.couchers.bugs.ReportDiagnosticsReq\x1a\x16.google.protobuf.Empty\"\x00\x12g\n\x11\x43heckNativeStatus\x12\'.org.couchers.bugs.CheckNativeStatusReq\x1a\'.org.couchers.bugs.CheckNativeStatusRes\"\x00\x12m\n\x13\x45valuateFeatureFlag\x12).org.couchers.bugs.EvaluateFeatureFlagReq\x1a).org.couchers.bugs.EvaluateFeatureFlagRes\"\x00\x12^\n\x15LogExperimentExposure\x12+.org.couchers.bugs.LogExperimentExposureReq\x1a\x16.google.protobuf.Empty\"\x00\x1a\x04\x88\xb5\x18\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bugs_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_BUGS']._loaded_options = None
  _globals['_BUGS']._serialized_options = b'\210\265\030\001'
  _globals['_BUGS'].methods_by_name['Version']._loaded_options = None
  _globals['_BUGS'].methods_by_name['Version']._serialized_options = b'\202\323\344\223\002\n\022\010/version'
  _globals['_BUGS'].methods_by_name['Status']._loaded_options = None
  _globals['_BUGS'].methods_by_name['Status']._serialized_options = b'\202\323\344\223\002\t\022\007/status'
  _globals['_BUGS'].methods_by_name['GetDescriptors']._loaded_options = None
  _globals['_BUGS'].methods_by_name['GetDescriptors']._serialized_options = b'\202\323\344\223\002\021\022\017/descriptors.pb'
  _globals['_BUGS'].methods_by_name['GetNativeUpdateManifest']._loaded_options = None
  _globals['_BUGS'].methods_by_name['GetNativeUpdateManifest']._serialized_options = b'\202\323\344\223\002\026\022\024/native/ota/manifest'
  _globals['_NATIVEUPDATEACTION']._serialized_start=2787
  _globals['_NATIVEUPDATEACTION']._serialized_end=2974
  _globals['_NATIVEUPDATECAUSE']._serialized_start=2976
  _globals['_NATIVEUPDATECAUSE']._serialized_end=3093
  _globals['_VERSIONINFO']._serialized_start=233
  _globals['_VERSIONINFO']._serialized_end=263
  _globals['_SCREENRESOLUTION']._serialized_start=265
  _globals['_SCREENRESOLUTION']._serialized_end=314
  _globals['_REPORTBUGREQ']._serialized_start=317
  _globals['_REPORTBUGREQ']._serialized_end=510
  _globals['_REPORTBUGRES']._serialized_start=512
  _globals['_REPORTBUGRES']._serialized_end=559
  _globals['_STATUSREQ']._serialized_start=561
  _globals['_STATUSREQ']._serialized_end=587
  _globals['_STATUSRES']._serialized_start=589
  _globals['_STATUSRES']._serialized_end=671
  _globals['_GEOLOCATIONSEARCHINFOREQ']._serialized_start=674
  _globals['_GEOLOCATIONSEARCHINFOREQ']._serialized_end=806
  _globals['_GEOLOCATIONCLICKINFOREQ']._serialized_start=808
  _globals['_GEOLOCATIONCLICKINFOREQ']._serialized_end=909
  _globals['_DIAGNOSTICINFO']._serialized_start=911
  _globals['_DIAGNOSTICINFO']._serialized_end=1026
  _globals['_REPORTDIAGNOSTICSREQ']._serialized_start=1028
  _globals['_REPORTDIAGNOSTICSREQ']._serialized_end=1126
  _globals['_CHECKNATIVESTATUSREQ']._serialized_start=1129
  _globals['_CHECKNATIVESTATUSREQ']._serialized_end=1939
  _globals['_NATIVEUPDATEINFO']._serialized_start=1942
  _globals['_NATIVEUPDATEINFO']._serialized_end=2233
  _globals['_CHECKNATIVESTATUSRES']._serialized_start=2235
  _globals['_CHECKNATIVESTATUSRES']._serialized_end=2315
  _globals['_EVALUATEFEATUREFLAGREQ']._serialized_start=2317
  _globals['_EVALUATEFEATUREFLAGREQ']._serialized_end=2359
  _globals['_EVALUATEFEATUREFLAGRES']._serialized_start=2361
  _globals['_EVALUATEFEATUREFLAGRES']._serialized_end=2424
  _globals['_LOGEXPERIMENTEXPOSUREREQ']._serialized_start=2427
  _globals['_LOGEXPERIMENTEXPOSUREREQ']._serialized_end=2784
  _globals['_BUGS']._serialized_start=3096
  _globals['_BUGS']._serialized_end=4141
# @@protoc_insertion_point(module_scope)
