# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: postal_verification.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import annotations_pb2 as annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19postal_verification.proto\x12$org.couchers.api.postal_verification\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x11\x61nnotations.proto\"\x87\x01\n\rPostalAddress\x12\x16\n\x0e\x61\x64\x64ress_line_1\x18\x01 \x01(\t\x12\x16\n\x0e\x61\x64\x64ress_line_2\x18\x02 \x01(\t\x12\x0c\n\x04\x63ity\x18\x03 \x01(\t\x12\r\n\x05state\x18\x04 \x01(\t\x12\x13\n\x0bpostal_code\x18\x05 \x01(\t\x12\x14\n\x0c\x63ountry_code\x18\x06 \x01(\t\"e\n\x1dInitiatePostalVerificationReq\x12\x44\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\x33.org.couchers.api.postal_verification.PostalAddress\"\xb6\x01\n\x1dInitiatePostalVerificationRes\x12&\n\x1epostal_verification_attempt_id\x18\x01 \x01(\x03\x12N\n\x11\x63orrected_address\x18\x02 \x01(\x0b\x32\x33.org.couchers.api.postal_verification.PostalAddress\x12\x1d\n\x15\x61\x64\x64ress_was_corrected\x18\x03 \x01(\x08\"A\n\x17\x43onfirmPostalAddressReq\x12&\n\x1epostal_verification_attempt_id\x18\x01 \x01(\x03\"\x19\n\x17\x43onfirmPostalAddressRes\"H\n\x1eGetPostalVerificationStatusReq\x12&\n\x1epostal_verification_attempt_id\x18\x01 \x01(\x03\"\xdd\x03\n\x1eGetPostalVerificationStatusRes\x12\x1f\n\x17has_postal_verification\x18\x01 \x01(\x08\x12\x1a\n\x12has_active_attempt\x18\x02 \x01(\x08\x12&\n\x1epostal_verification_attempt_id\x18\x03 \x01(\x03\x12N\n\x06status\x18\x04 \x01(\x0e\x32>.org.couchers.api.postal_verification.PostalVerificationStatus\x12\x44\n\x07\x61\x64\x64ress\x18\x05 \x01(\x0b\x32\x33.org.couchers.api.postal_verification.PostalAddress\x12+\n\x07\x63reated\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x10postcard_sent_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12 \n\x18\x63\x61n_initiate_new_attempt\x18\x08 \x01(\x08\x12;\n\x17next_attempt_allowed_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"#\n\x13VerifyPostalCodeReq\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\"B\n\x13VerifyPostalCodeRes\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x1a\n\x12remaining_attempts\x18\x02 \x01(\x05\"E\n\x1b\x43\x61ncelPostalVerificationReq\x12&\n\x1epostal_verification_attempt_id\x18\x01 \x01(\x03\"#\n!ListPostalVerificationAttemptsReq\"}\n!ListPostalVerificationAttemptsRes\x12X\n\x08\x61ttempts\x18\x01 \x03(\x0b\x32\x46.org.couchers.api.postal_verification.PostalVerificationAttemptSummary\"\xbe\x02\n PostalVerificationAttemptSummary\x12&\n\x1epostal_verification_attempt_id\x18\x01 \x01(\x03\x12N\n\x06status\x18\x02 \x01(\x0e\x32>.org.couchers.api.postal_verification.PostalVerificationStatus\x12\x44\n\x07\x61\x64\x64ress\x18\x03 \x01(\x0b\x32\x33.org.couchers.api.postal_verification.PostalAddress\x12+\n\x07\x63reated\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0bverified_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp*\xdc\x02\n\x18PostalVerificationStatus\x12&\n\"POSTAL_VERIFICATION_STATUS_UNKNOWN\x10\x00\x12;\n7POSTAL_VERIFICATION_STATUS_PENDING_ADDRESS_CONFIRMATION\x10\x01\x12*\n&POSTAL_VERIFICATION_STATUS_IN_PROGRESS\x10\x02\x12\x34\n0POSTAL_VERIFICATION_STATUS_AWAITING_VERIFICATION\x10\x03\x12(\n$POSTAL_VERIFICATION_STATUS_SUCCEEDED\x10\x04\x12%\n!POSTAL_VERIFICATION_STATUS_FAILED\x10\x05\x12(\n$POSTAL_VERIFICATION_STATUS_CANCELLED\x10\x06\x32\xc9\x07\n\x12PostalVerification\x12\xa8\x01\n\x1aInitiatePostalVerification\x12\x43.org.couchers.api.postal_verification.InitiatePostalVerificationReq\x1a\x43.org.couchers.api.postal_verification.InitiatePostalVerificationRes\"\x00\x12\x96\x01\n\x14\x43onfirmPostalAddress\x12=.org.couchers.api.postal_verification.ConfirmPostalAddressReq\x1a=.org.couchers.api.postal_verification.ConfirmPostalAddressRes\"\x00\x12\xab\x01\n\x1bGetPostalVerificationStatus\x12\x44.org.couchers.api.postal_verification.GetPostalVerificationStatusReq\x1a\x44.org.couchers.api.postal_verification.GetPostalVerificationStatusRes\"\x00\x12\x8a\x01\n\x10VerifyPostalCode\x12\x39.org.couchers.api.postal_verification.VerifyPostalCodeReq\x1a\x39.org.couchers.api.postal_verification.VerifyPostalCodeRes\"\x00\x12w\n\x18\x43\x61ncelPostalVerification\x12\x41.org.couchers.api.postal_verification.CancelPostalVerificationReq\x1a\x16.google.protobuf.Empty\"\x00\x12\xb4\x01\n\x1eListPostalVerificationAttempts\x12G.org.couchers.api.postal_verification.ListPostalVerificationAttemptsReq\x1aG.org.couchers.api.postal_verification.ListPostalVerificationAttemptsRes\"\x00\x1a\x04\x88\xb5\x18\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'postal_verification_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_POSTALVERIFICATION']._loaded_options = None
  _globals['_POSTALVERIFICATION']._serialized_options = b'\210\265\030\003'
  _globals['_POSTALVERIFICATIONSTATUS']._serialized_start=1884
  _globals['_POSTALVERIFICATIONSTATUS']._serialized_end=2232
  _globals['_POSTALADDRESS']._serialized_start=149
  _globals['_POSTALADDRESS']._serialized_end=284
  _globals['_INITIATEPOSTALVERIFICATIONREQ']._serialized_start=286
  _globals['_INITIATEPOSTALVERIFICATIONREQ']._serialized_end=387
  _globals['_INITIATEPOSTALVERIFICATIONRES']._serialized_start=390
  _globals['_INITIATEPOSTALVERIFICATIONRES']._serialized_end=572
  _globals['_CONFIRMPOSTALADDRESSREQ']._serialized_start=574
  _globals['_CONFIRMPOSTALADDRESSREQ']._serialized_end=639
  _globals['_CONFIRMPOSTALADDRESSRES']._serialized_start=641
  _globals['_CONFIRMPOSTALADDRESSRES']._serialized_end=666
  _globals['_GETPOSTALVERIFICATIONSTATUSREQ']._serialized_start=668
  _globals['_GETPOSTALVERIFICATIONSTATUSREQ']._serialized_end=740
  _globals['_GETPOSTALVERIFICATIONSTATUSRES']._serialized_start=743
  _globals['_GETPOSTALVERIFICATIONSTATUSRES']._serialized_end=1220
  _globals['_VERIFYPOSTALCODEREQ']._serialized_start=1222
  _globals['_VERIFYPOSTALCODEREQ']._serialized_end=1257
  _globals['_VERIFYPOSTALCODERES']._serialized_start=1259
  _globals['_VERIFYPOSTALCODERES']._serialized_end=1325
  _globals['_CANCELPOSTALVERIFICATIONREQ']._serialized_start=1327
  _globals['_CANCELPOSTALVERIFICATIONREQ']._serialized_end=1396
  _globals['_LISTPOSTALVERIFICATIONATTEMPTSREQ']._serialized_start=1398
  _globals['_LISTPOSTALVERIFICATIONATTEMPTSREQ']._serialized_end=1433
  _globals['_LISTPOSTALVERIFICATIONATTEMPTSRES']._serialized_start=1435
  _globals['_LISTPOSTALVERIFICATIONATTEMPTSRES']._serialized_end=1560
  _globals['_POSTALVERIFICATIONATTEMPTSUMMARY']._serialized_start=1563
  _globals['_POSTALVERIFICATIONATTEMPTSUMMARY']._serialized_end=1881
  _globals['_POSTALVERIFICATION']._serialized_start=2235
  _globals['_POSTALVERIFICATION']._serialized_end=3204
# @@protoc_insertion_point(module_scope)
