# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: resources.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from . import annotations_pb2 as annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fresources.proto\x12\x16org.couchers.resources\x1a\x1bgoogle/protobuf/empty.proto\x1a\x11\x61nnotations.proto\"0\n\x14GetTermsOfServiceRes\x12\x18\n\x10terms_of_service\x18\x01 \x01(\t\"H\n\x12\x43ommunityGuideline\x12\r\n\x05title\x18\x01 \x01(\t\x12\x11\n\tguideline\x18\x02 \x01(\t\x12\x10\n\x08icon_svg\x18\x03 \x01(\t\"e\n\x19GetCommunityGuidelinesRes\x12H\n\x14\x63ommunity_guidelines\x18\x01 \x03(\x0b\x32*.org.couchers.resources.CommunityGuideline\"&\n\x06Region\x12\x0e\n\x06\x61lpha3\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"@\n\rGetRegionsRes\x12/\n\x07regions\x18\x01 \x03(\x0b\x32\x1e.org.couchers.resources.Region\"&\n\x08Language\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"F\n\x0fGetLanguagesRes\x12\x33\n\tlanguages\x18\x01 \x03(\x0b\x32 .org.couchers.resources.Language\"E\n\x05\x42\x61\x64ge\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\r\n\x05\x63olor\x18\x04 \x01(\t\"=\n\x0cGetBadgesRes\x12-\n\x06\x62\x61\x64ges\x18\x01 \x03(\x0b\x32\x1d.org.couchers.resources.Badge2\xc4\x03\n\tResources\x12[\n\x11GetTermsOfService\x12\x16.google.protobuf.Empty\x1a,.org.couchers.resources.GetTermsOfServiceRes\"\x00\x12\x65\n\x16GetCommunityGuidelines\x12\x16.google.protobuf.Empty\x1a\x31.org.couchers.resources.GetCommunityGuidelinesRes\"\x00\x12M\n\nGetRegions\x12\x16.google.protobuf.Empty\x1a%.org.couchers.resources.GetRegionsRes\"\x00\x12Q\n\x0cGetLanguages\x12\x16.google.protobuf.Empty\x1a\'.org.couchers.resources.GetLanguagesRes\"\x00\x12K\n\tGetBadges\x12\x16.google.protobuf.Empty\x1a$.org.couchers.resources.GetBadgesRes\"\x00\x1a\x04\x88\xb5\x18\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'resources_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_RESOURCES']._loaded_options = None
  _globals['_RESOURCES']._serialized_options = b'\210\265\030\001'
  _globals['_GETTERMSOFSERVICERES']._serialized_start=91
  _globals['_GETTERMSOFSERVICERES']._serialized_end=139
  _globals['_COMMUNITYGUIDELINE']._serialized_start=141
  _globals['_COMMUNITYGUIDELINE']._serialized_end=213
  _globals['_GETCOMMUNITYGUIDELINESRES']._serialized_start=215
  _globals['_GETCOMMUNITYGUIDELINESRES']._serialized_end=316
  _globals['_REGION']._serialized_start=318
  _globals['_REGION']._serialized_end=356
  _globals['_GETREGIONSRES']._serialized_start=358
  _globals['_GETREGIONSRES']._serialized_end=422
  _globals['_LANGUAGE']._serialized_start=424
  _globals['_LANGUAGE']._serialized_end=462
  _globals['_GETLANGUAGESRES']._serialized_start=464
  _globals['_GETLANGUAGESRES']._serialized_end=534
  _globals['_BADGE']._serialized_start=536
  _globals['_BADGE']._serialized_end=605
  _globals['_GETBADGESRES']._serialized_start=607
  _globals['_GETBADGESRES']._serialized_end=668
  _globals['_RESOURCES']._serialized_start=671
  _globals['_RESOURCES']._serialized_end=1123
# @@protoc_insertion_point(module_scope)
