# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import communities_pb2 as communities__pb2
from . import editor_pb2 as editor__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class EditorStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateCommunity = channel.unary_unary(
                '/org.couchers.editor.Editor/CreateCommunity',
                request_serializer=editor__pb2.CreateCommunityReq.SerializeToString,
                response_deserializer=communities__pb2.Community.FromString,
                )
        self.UpdateCommunity = channel.unary_unary(
                '/org.couchers.editor.Editor/UpdateCommunity',
                request_serializer=editor__pb2.UpdateCommunityReq.SerializeToString,
                response_deserializer=communities__pb2.Community.FromString,
                )
        self.ListEventCommunityInviteRequests = channel.unary_unary(
                '/org.couchers.editor.Editor/ListEventCommunityInviteRequests',
                request_serializer=editor__pb2.ListEventCommunityInviteRequestsReq.SerializeToString,
                response_deserializer=editor__pb2.ListEventCommunityInviteRequestsRes.FromString,
                )
        self.DecideEventCommunityInviteRequest = channel.unary_unary(
                '/org.couchers.editor.Editor/DecideEventCommunityInviteRequest',
                request_serializer=editor__pb2.DecideEventCommunityInviteRequestReq.SerializeToString,
                response_deserializer=editor__pb2.DecideEventCommunityInviteRequestRes.FromString,
                )
        self.SendBlogPostNotification = channel.unary_unary(
                '/org.couchers.editor.Editor/SendBlogPostNotification',
                request_serializer=editor__pb2.SendBlogPostNotificationReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.MakeUserVolunteer = channel.unary_unary(
                '/org.couchers.editor.Editor/MakeUserVolunteer',
                request_serializer=editor__pb2.MakeUserVolunteerReq.SerializeToString,
                response_deserializer=editor__pb2.Volunteer.FromString,
                )
        self.UpdateVolunteer = channel.unary_unary(
                '/org.couchers.editor.Editor/UpdateVolunteer',
                request_serializer=editor__pb2.UpdateVolunteerReq.SerializeToString,
                response_deserializer=editor__pb2.Volunteer.FromString,
                )
        self.ListVolunteers = channel.unary_unary(
                '/org.couchers.editor.Editor/ListVolunteers',
                request_serializer=editor__pb2.ListVolunteersReq.SerializeToString,
                response_deserializer=editor__pb2.ListVolunteersRes.FromString,
                )
        self.ListPostcards = channel.unary_unary(
                '/org.couchers.editor.Editor/ListPostcards',
                request_serializer=editor__pb2.ListPostcardsReq.SerializeToString,
                response_deserializer=editor__pb2.ListPostcardsRes.FromString,
                )
        self.DownloadPostcardPdf = channel.unary_unary(
                '/org.couchers.editor.Editor/DownloadPostcardPdf',
                request_serializer=editor__pb2.DownloadPostcardPdfReq.SerializeToString,
                response_deserializer=editor__pb2.DownloadPostcardPdfRes.FromString,
                )


class EditorServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateCommunity(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateCommunity(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListEventCommunityInviteRequests(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DecideEventCommunityInviteRequest(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendBlogPostNotification(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MakeUserVolunteer(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateVolunteer(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListVolunteers(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListPostcards(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DownloadPostcardPdf(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_EditorServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateCommunity': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateCommunity,
                    request_deserializer=editor__pb2.CreateCommunityReq.FromString,
                    response_serializer=communities__pb2.Community.SerializeToString,
            ),
            'UpdateCommunity': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateCommunity,
                    request_deserializer=editor__pb2.UpdateCommunityReq.FromString,
                    response_serializer=communities__pb2.Community.SerializeToString,
            ),
            'ListEventCommunityInviteRequests': grpc.unary_unary_rpc_method_handler(
                    servicer.ListEventCommunityInviteRequests,
                    request_deserializer=editor__pb2.ListEventCommunityInviteRequestsReq.FromString,
                    response_serializer=editor__pb2.ListEventCommunityInviteRequestsRes.SerializeToString,
            ),
            'DecideEventCommunityInviteRequest': grpc.unary_unary_rpc_method_handler(
                    servicer.DecideEventCommunityInviteRequest,
                    request_deserializer=editor__pb2.DecideEventCommunityInviteRequestReq.FromString,
                    response_serializer=editor__pb2.DecideEventCommunityInviteRequestRes.SerializeToString,
            ),
            'SendBlogPostNotification': grpc.unary_unary_rpc_method_handler(
                    servicer.SendBlogPostNotification,
                    request_deserializer=editor__pb2.SendBlogPostNotificationReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'MakeUserVolunteer': grpc.unary_unary_rpc_method_handler(
                    servicer.MakeUserVolunteer,
                    request_deserializer=editor__pb2.MakeUserVolunteerReq.FromString,
                    response_serializer=editor__pb2.Volunteer.SerializeToString,
            ),
            'UpdateVolunteer': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateVolunteer,
                    request_deserializer=editor__pb2.UpdateVolunteerReq.FromString,
                    response_serializer=editor__pb2.Volunteer.SerializeToString,
            ),
            'ListVolunteers': grpc.unary_unary_rpc_method_handler(
                    servicer.ListVolunteers,
                    request_deserializer=editor__pb2.ListVolunteersReq.FromString,
                    response_serializer=editor__pb2.ListVolunteersRes.SerializeToString,
            ),
            'ListPostcards': grpc.unary_unary_rpc_method_handler(
                    servicer.ListPostcards,
                    request_deserializer=editor__pb2.ListPostcardsReq.FromString,
                    response_serializer=editor__pb2.ListPostcardsRes.SerializeToString,
            ),
            'DownloadPostcardPdf': grpc.unary_unary_rpc_method_handler(
                    servicer.DownloadPostcardPdf,
                    request_deserializer=editor__pb2.DownloadPostcardPdfReq.FromString,
                    response_serializer=editor__pb2.DownloadPostcardPdfRes.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'org.couchers.editor.Editor', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Editor(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateCommunity(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.editor.Editor/CreateCommunity',
            editor__pb2.CreateCommunityReq.SerializeToString,
            communities__pb2.Community.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateCommunity(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.editor.Editor/UpdateCommunity',
            editor__pb2.UpdateCommunityReq.SerializeToString,
            communities__pb2.Community.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListEventCommunityInviteRequests(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.editor.Editor/ListEventCommunityInviteRequests',
            editor__pb2.ListEventCommunityInviteRequestsReq.SerializeToString,
            editor__pb2.ListEventCommunityInviteRequestsRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DecideEventCommunityInviteRequest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.editor.Editor/DecideEventCommunityInviteRequest',
            editor__pb2.DecideEventCommunityInviteRequestReq.SerializeToString,
            editor__pb2.DecideEventCommunityInviteRequestRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendBlogPostNotification(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.editor.Editor/SendBlogPostNotification',
            editor__pb2.SendBlogPostNotificationReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def MakeUserVolunteer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.editor.Editor/MakeUserVolunteer',
            editor__pb2.MakeUserVolunteerReq.SerializeToString,
            editor__pb2.Volunteer.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateVolunteer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.editor.Editor/UpdateVolunteer',
            editor__pb2.UpdateVolunteerReq.SerializeToString,
            editor__pb2.Volunteer.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListVolunteers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.editor.Editor/ListVolunteers',
            editor__pb2.ListVolunteersReq.SerializeToString,
            editor__pb2.ListVolunteersRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListPostcards(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.editor.Editor/ListPostcards',
            editor__pb2.ListPostcardsReq.SerializeToString,
            editor__pb2.ListPostcardsRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DownloadPostcardPdf(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.editor.Editor/DownloadPostcardPdf',
            editor__pb2.DownloadPostcardPdfReq.SerializeToString,
            editor__pb2.DownloadPostcardPdfRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
