from sqlalchemy import orm
from couchers.context import CouchersContext
"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import google.protobuf.empty_pb2
import grpc
import grpc.aio
import reporting_pb2
import typing


GRPC_GENERATED_VERSION: str
GRPC_VERSION: str

class ReportingStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    Report: grpc.UnaryUnaryMultiCallable[reporting_pb2.ReportReq, google.protobuf.empty_pb2.Empty]
    """Report content, user, or something else"""

class ReportingServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def Report(
        self,
        request: reporting_pb2.ReportReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.protobuf.empty_pb2.Empty:
        """Report content, user, or something else"""

def add_ReportingServicer_to_server(servicer: ReportingServicer, server: grpc.Server) -> None: ...
