# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from . import annotations_pb2 as annotations__pb2
from . import api_pb2 as api__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0b\x61\x64min.proto\x12\x12org.couchers.admin\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x11\x61nnotations.proto\x1a\tapi.proto\"\xa9\x02\n\x0e\x41\x64minActionLog\x12\x17\n\x0f\x61\x64min_action_id\x18\x01 \x01(\x03\x12+\n\x07\x63reated\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x15\n\radmin_user_id\x18\x03 \x01(\x03\x12\x16\n\x0e\x61\x64min_username\x18\x04 \x01(\t\x12\x13\n\x0b\x61\x63tion_type\x18\x05 \x01(\t\x12\x0c\n\x04note\x18\x06 \x01(\t\x12\x0b\n\x03tag\x18\x07 \x01(\t\x12\x33\n\x05level\x18\x08 \x01(\x0e\x32$.org.couchers.admin.AdminActionLevel\x12\x16\n\x0etarget_user_id\x18\t \x01(\x03\x12\x17\n\x0ftarget_username\x18\n \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x0b \x01(\t\"1\n\x0c\x41\x64minTagInfo\x12\x14\n\x0c\x61\x64min_tag_id\x18\x01 \x01(\x03\x12\x0b\n\x03tag\x18\x02 \x01(\t\"\xc0\x05\n\x0bUserDetails\x12\x0f\n\x07user_id\x18\x01 \x01(\x03\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x0e \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\x12\x0e\n\x06gender\x18\x04 \x01(\t\x12\x11\n\tbirthdate\x18\x07 \x01(\t\x12\x0e\n\x06\x62\x61nned\x18\x05 \x01(\x08\x12\x0f\n\x07\x64\x65leted\x18\x06 \x01(\x08\x12\x10\n\x08shadowed\x18\x15 \x01(\x08\x12\x14\n\x0c\x64o_not_email\x18\x0f \x01(\x08\x12\x0e\n\x06\x62\x61\x64ges\x18\x08 \x03(\t\x12\x1f\n\x17has_strong_verification\x18\t \x01(\x08\x12Y\n\x1d\x62irthdate_verification_status\x18\n \x01(\x0e\x32\x32.org.couchers.api.core.BirthdateVerificationStatus\x12S\n\x1agender_verification_status\x18\x0b \x01(\x0e\x32/.org.couchers.api.core.GenderVerificationStatus\x12)\n!has_passport_sex_gender_exception\x18\x0c \x01(\x08\x12\x1f\n\x17pending_mod_notes_count\x18\x10 \x01(\x03\x12$\n\x1c\x61\x63knowledged_mod_notes_count\x18\x11 \x01(\x03\x12>\n\x1alast_mod_note_acknowledged\x18\x16 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\radmin_actions\x18\x12 \x03(\x0b\x32\".org.couchers.admin.AdminActionLog\x12\x12\n\nadmin_tags\x18\x13 \x03(\t\x12\x11\n\tmod_score\x18\x14 \x01(\x01J\x04\x08\r\x10\x0eR\nadmin_note\"!\n\x11GetUserDetailsReq\x12\x0c\n\x04user\x18\x01 \x01(\t\"\x1a\n\nGetUserReq\x12\x0c\n\x04user\x18\x01 \x01(\t\"\xd1\x04\n\x0eSearchUsersReq\x12\x10\n\x08username\x18\x03 \x01(\t\x12\r\n\x05\x65mail\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x18\n\x10\x61\x64min_action_log\x18\x06 \x01(\t\x12\x0c\n\x04\x63ity\x18\x07 \x01(\t\x12\x13\n\x0bmin_user_id\x18\x08 \x01(\x03\x12\x13\n\x0bmax_user_id\x18\t \x01(\x03\x12\x15\n\rmin_birthdate\x18\n \x01(\t\x12\x15\n\rmax_birthdate\x18\x0b \x01(\t\x12\x17\n\x0fmin_joined_date\x18\x0c \x01(\t\x12\x17\n\x0fmax_joined_date\x18\r \x01(\t\x12\x1c\n\x14min_last_active_date\x18\x0e \x01(\t\x12\x1c\n\x14max_last_active_date\x18\x0f \x01(\t\x12\x0f\n\x07genders\x18\x10 \x03(\t\x12\x16\n\x0elanguage_codes\x18\x11 \x03(\t\x12.\n\nis_deleted\x18\x12 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12-\n\tis_banned\x18\x13 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12/\n\x0bis_shadowed\x18\x16 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12.\n\nhas_avatar\x18\x14 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x12\n\nadmin_tags\x18\x15 \x03(\t\x12\x11\n\tpage_size\x18\x01 \x01(\r\x12\x12\n\npage_token\x18\x02 \x01(\t\"Y\n\x0eSearchUsersRes\x12.\n\x05users\x18\x01 \x03(\x0b\x32\x1f.org.couchers.admin.UserDetails\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"3\n\x13\x43hangeUserGenderReq\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0e\n\x06gender\x18\x02 \x01(\t\"9\n\x16\x43hangeUserBirthdateReq\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x11\n\tbirthdate\x18\x02 \x01(\t\"-\n\x0b\x41\x64\x64\x42\x61\x64geReq\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x10\n\x08\x62\x61\x64ge_id\x18\x02 \x01(\t\"0\n\x0eRemoveBadgeReq\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x10\n\x08\x62\x61\x64ge_id\x18\x02 \x01(\t\"W\n SetPassportSexGenderExceptionReq\x12\x0c\n\x04user\x18\x01 \x01(\t\x12%\n\x1dpassport_sex_gender_exception\x18\x02 \x01(\x08\".\n\nBanUserReq\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x12\n\nadmin_note\x18\x02 \x01(\t\"0\n\x0cUnbanUserReq\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x12\n\nadmin_note\x18\x02 \x01(\t\"1\n\rShadowUserReq\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x12\n\nadmin_note\x18\x02 \x01(\t\"3\n\x0fUnshadowUserReq\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x12\n\nadmin_note\x18\x02 \x01(\t\"v\n\x0f\x41\x64\x64\x41\x64minNoteReq\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x12\n\nadmin_note\x18\x02 \x01(\t\x12\x33\n\x05level\x18\x03 \x01(\x0e\x32$.org.couchers.admin.AdminActionLevel\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\t\"\xe3\x01\n\rContentReport\x12\x19\n\x11\x63ontent_report_id\x18\x01 \x01(\x03\x12(\n\x04time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x19\n\x11reporting_user_id\x18\x03 \x01(\x03\x12\x16\n\x0e\x61uthor_user_id\x18\x04 \x01(\x03\x12\x0e\n\x06reason\x18\x05 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x12\x13\n\x0b\x63ontent_ref\x18\x07 \x01(\t\x12\x12\n\nuser_agent\x18\x08 \x01(\t\x12\x0c\n\x04page\x18\t \x01(\t\"0\n\x13GetContentReportReq\x12\x19\n\x11\x63ontent_report_id\x18\x01 \x01(\x03\"P\n\x13GetContentReportRes\x12\x39\n\x0e\x63ontent_report\x18\x01 \x01(\x0b\x32!.org.couchers.admin.ContentReport\"-\n\x1dGetContentReportsForAuthorReq\x12\x0c\n\x04user\x18\x01 \x01(\t\"[\n\x1dGetContentReportsForAuthorRes\x12:\n\x0f\x63ontent_reports\x18\x01 \x03(\x0b\x32!.org.couchers.admin.ContentReport\"[\n\x0eSendModNoteReq\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\x12\x13\n\x0binternal_id\x18\x03 \x01(\t\x12\x15\n\rdo_not_notify\x18\x04 \x01(\x08\".\n\x1eMarkUserNeedsLocationUpdateReq\x12\x0c\n\x04user\x18\x01 \x01(\t\"\x1d\n\rDeleteUserReq\x12\x0c\n\x04user\x18\x01 \x01(\t\"%\n\x15RecoverDeletedUserReq\x12\x0c\n\x04user\x18\x01 \x01(\t\"\x1f\n\x0f\x43reateApiKeyReq\x12\x0c\n\x04user\x18\x01 \x01(\t\"\x11\n\x0f\x43reateApiKeyRes\"\x1b\n\x0bGetChatsReq\x12\x0c\n\x04user\x18\x01 \x01(\t\"b\n\x0c\x43hatUserInfo\x12\x0f\n\x07user_id\x18\x01 \x01(\x03\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x11\n\tbirthdate\x18\x04 \x01(\t\x12\x0e\n\x06gender\x18\x05 \x01(\t\"\xf7\x01\n\x0b\x43hatMessage\x12\x12\n\nmessage_id\x18\x01 \x01(\x03\x12\x30\n\x06\x61uthor\x18\x02 \x01(\x0b\x32 .org.couchers.admin.ChatUserInfo\x12(\n\x04time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x14\n\x0cmessage_type\x18\x04 \x01(\t\x12\x0c\n\x04text\x18\x05 \x01(\t\x12\"\n\x1ahost_request_status_target\x18\x06 \x01(\t\x12\x30\n\x06target\x18\x07 \x01(\x0b\x32 .org.couchers.admin.ChatUserInfo\"\xa5\x01\n\x0fGroupChatMember\x12.\n\x04user\x18\x01 \x01(\x0b\x32 .org.couchers.admin.ChatUserInfo\x12*\n\x06joined\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04left\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04role\x18\x04 \x01(\t\"\xe1\x01\n\x0e\x41\x64minGroupChat\x12\x15\n\rgroup_chat_id\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\x12\r\n\x05is_dm\x18\x03 \x01(\x08\x12\x31\n\x07\x63reator\x18\x04 \x01(\x0b\x32 .org.couchers.admin.ChatUserInfo\x12\x34\n\x07members\x18\x05 \x03(\x0b\x32#.org.couchers.admin.GroupChatMember\x12\x31\n\x08messages\x18\x06 \x03(\x0b\x32\x1f.org.couchers.admin.ChatMessage\"\xa1\x02\n\x10\x41\x64minHostRequest\x12\x17\n\x0fhost_request_id\x18\x01 \x01(\x03\x12\x30\n\x06surfer\x18\x02 \x01(\x0b\x32 .org.couchers.admin.ChatUserInfo\x12.\n\x04host\x18\x03 \x01(\x0b\x32 .org.couchers.admin.ChatUserInfo\x12\x0e\n\x06status\x18\x04 \x01(\t\x12\x11\n\tfrom_date\x18\x05 \x01(\t\x12\x0f\n\x07to_date\x18\x06 \x01(\t\x12+\n\x07\x63reated\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\x08messages\x18\x08 \x03(\x0b\x32\x1f.org.couchers.admin.ChatMessage\"\xb3\x01\n\x0bGetChatsRes\x12.\n\x04user\x18\x01 \x01(\x0b\x32 .org.couchers.admin.ChatUserInfo\x12;\n\rhost_requests\x18\x02 \x03(\x0b\x32$.org.couchers.admin.AdminHostRequest\x12\x37\n\x0bgroup_chats\x18\x03 \x03(\x0b\x32\".org.couchers.admin.AdminGroupChat\"\"\n\x0e\x44\x65leteEventReq\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\x03\"\x95\x01\n\x0eListUserIdsReq\x12.\n\nstart_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\tpage_size\x18\x03 \x01(\r\x12\x12\n\npage_token\x18\x04 \x01(\t\";\n\x0eListUserIdsRes\x12\x10\n\x08user_ids\x18\x01 \x03(\x03\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\">\n\x14\x45\x64itReferenceTextReq\x12\x14\n\x0creference_id\x18\x01 \x01(\x03\x12\x10\n\x08new_text\x18\x02 \x01(\t\"*\n\x12\x44\x65leteReferenceReq\x12\x14\n\x0creference_id\x18\x01 \x01(\x03\"$\n\x14GetUserReferencesReq\x12\x0c\n\x04user\x18\x01 \x01(\t\"\x8a\x02\n\x0e\x41\x64minReference\x12\x14\n\x0creference_id\x18\x01 \x01(\x03\x12\x14\n\x0c\x66rom_user_id\x18\x02 \x01(\x03\x12\x12\n\nto_user_id\x18\x03 \x01(\x03\x12\x16\n\x0ereference_type\x18\x04 \x01(\t\x12\x0c\n\x04text\x18\x05 \x01(\t\x12\x14\n\x0cprivate_text\x18\x06 \x01(\t\x12(\n\x04time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x17\n\x0fhost_request_id\x18\x08 \x01(\x03\x12\x0e\n\x06rating\x18\t \x01(\x01\x12\x17\n\x0fwas_appropriate\x18\n \x01(\x08J\x04\x08\x0b\x10\x0cR\nis_deleted\"\x8e\x01\n\x14GetUserReferencesRes\x12;\n\x0freferences_from\x18\x01 \x03(\x0b\x32\".org.couchers.admin.AdminReference\x12\x39\n\rreferences_to\x18\x02 \x03(\x0b\x32\".org.couchers.admin.AdminReference\"$\n\x14GetFriendRequestsReq\x12\x0c\n\x04user\x18\x01 \x01(\t\"\xa9\x02\n\x12\x41\x64minFriendRequest\x12\x19\n\x11\x66riend_request_id\x18\x01 \x01(\x03\x12\x33\n\tfrom_user\x18\x02 \x01(\x0b\x32 .org.couchers.admin.ChatUserInfo\x12\x31\n\x07to_user\x18\x03 \x01(\x0b\x32 .org.couchers.admin.ChatUserInfo\x12\x0e\n\x06status\x18\x04 \x01(\t\x12-\n\ttime_sent\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x0etime_responded\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1d\n\x15moderation_visibility\x18\x07 \x01(\t\"\x86\x01\n\x14GetFriendRequestsRes\x12\x34\n\x04sent\x18\x01 \x03(\x0b\x32&.org.couchers.admin.AdminFriendRequest\x12\x38\n\x08received\x18\x02 \x03(\x0b\x32&.org.couchers.admin.AdminFriendRequest\"-\n\x1dGetNonvisibleUserAccessLogReq\x12\x0c\n\x04user\x18\x01 \x01(\t\"\xe4\x02\n\x1cNonvisibleUserAccessLogEntry\x12(\n\x04time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x41\n\x0b\x61\x63\x63\x65ss_type\x18\x02 \x01(\x0e\x32,.org.couchers.admin.NonvisibleUserAccessType\x12=\n\x0ctarget_state\x18\x03 \x01(\x0e\x32\'.org.couchers.admin.NonvisibleUserState\x12\x16\n\x0etarget_user_id\x18\x04 \x01(\x03\x12\x32\n\ractor_user_id\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x16\n\x0e\x61\x63tor_username\x18\x06 \x01(\t\x12\x12\n\nip_address\x18\x07 \x01(\t\x12\x12\n\nuser_agent\x18\x08 \x01(\t\x12\x0c\n\x04sofa\x18\t \x01(\t\"b\n\x1dGetNonvisibleUserAccessLogRes\x12\x41\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x30.org.couchers.admin.NonvisibleUserAccessLogEntry\"R\n\x11\x45\x64itDiscussionReq\x12\x15\n\rdiscussion_id\x18\x01 \x01(\x03\x12\x11\n\tnew_title\x18\x02 \x01(\t\x12\x13\n\x0bnew_content\x18\x03 \x01(\t\"1\n\x18\x41\x64minDeleteDiscussionReq\x12\x15\n\rdiscussion_id\x18\x01 \x01(\x03\"5\n\x0c\x45\x64itReplyReq\x12\x10\n\x08reply_id\x18\x01 \x01(\x03\x12\x13\n\x0bnew_content\x18\x02 \x01(\t\"L\n\x1f\x41\x64\x64UsersToModerationUserListReq\x12\r\n\x05users\x18\x01 \x03(\t\x12\x1a\n\x12moderation_list_id\x18\x02 \x01(\x03\"*\n\x1aListModerationUserListsReq\x12\x0c\n\x04user\x18\x01 \x01(\t\"p\n\x0eModerationList\x12\x1a\n\x12moderation_list_id\x18\x01 \x01(\x03\x12\x30\n\x07members\x18\x03 \x03(\x0b\x32\x1f.org.couchers.admin.UserDetailsJ\x04\x08\x02\x10\x03R\nmember_ids\"Z\n\x1aListModerationUserListsRes\x12<\n\x10moderation_lists\x18\x01 \x03(\x0b\x32\".org.couchers.admin.ModerationList\"=\n\x1f\x41\x64\x64UsersToModerationUserListRes\x12\x1a\n\x12moderation_list_id\x18\x01 \x01(\x03\"O\n#RemoveUserFromModerationUserListReq\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x1a\n\x12moderation_list_id\x18\x02 \x01(\x03\"A\n\x1c\x43reateAccountDeletionLinkReq\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x13\n\x0b\x65xpiry_days\x18\x02 \x01(\x03\"D\n\x1c\x43reateAccountDeletionLinkRes\x12$\n\x1c\x61\x63\x63ount_deletion_confirm_url\x18\x01 \x01(\t\"|\n\x0e\x41\x63\x63\x65ssStatsReq\x12\x0c\n\x04user\x18\x01 \x01(\t\x12.\n\nstart_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xca\x02\n\nAccessStat\x12\x12\n\nip_address\x18\x01 \x01(\t\x12\x0b\n\x03\x61sn\x18\x02 \x01(\t\x12\r\n\x05\x61sorg\x18\x03 \x01(\t\x12\x11\n\tasnetwork\x18\x04 \x01(\t\x12\x12\n\nuser_agent\x18\x05 \x01(\t\x12\x18\n\x10operating_system\x18\x06 \x01(\t\x12\x0f\n\x07\x62rowser\x18\x07 \x01(\t\x12\x0e\n\x06\x64\x65vice\x18\x08 \x01(\t\x12\x1c\n\x14\x61pproximate_location\x18\t \x01(\t\x12\x16\n\x0e\x61pi_call_count\x18\n \x01(\x04\x12\x15\n\rperiods_count\x18\x0b \x01(\x04\x12.\n\nfirst_seen\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\tlast_seen\x18\r \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"?\n\x0e\x41\x63\x63\x65ssStatsRes\x12-\n\x05stats\x18\x01 \x03(\x0b\x32\x1e.org.couchers.admin.AccessStat\"S\n\x11SetLastDonatedReq\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x30\n\x0clast_donated\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\" \n\x11\x43reateAdminTagReq\x12\x0b\n\x03tag\x18\x01 \x01(\t\"\x12\n\x10ListAdminTagsReq\"B\n\x10ListAdminTagsRes\x12.\n\x04tags\x18\x01 \x03(\x0b\x32 .org.couchers.admin.AdminTagInfo\"1\n\x14\x41\x64\x64\x41\x64minTagToUserReq\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0b\n\x03tag\x18\x02 \x01(\t\"6\n\x19RemoveAdminTagFromUserReq\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0b\n\x03tag\x18\x02 \x01(\t\"1\n\x0eSetModScoreReq\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x11\n\tmod_score\x18\x02 \x01(\x01\"k\n\x13ListAdminActionsReq\x12\x15\n\radmin_user_id\x18\x01 \x01(\x03\x12\x16\n\x0etarget_user_id\x18\x02 \x01(\x03\x12\x11\n\tpage_size\x18\x03 \x01(\r\x12\x12\n\npage_token\x18\x04 \x01(\t\"i\n\x13ListAdminActionsRes\x12\x39\n\radmin_actions\x18\x01 \x03(\x0b\x32\".org.couchers.admin.AdminActionLog\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"I\n\x12ListUserUploadsReq\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x91\x01\n\tUploadUse\x12/\n\x04type\x18\x01 \x01(\x0e\x32!.org.couchers.admin.UploadUseType\x12\x12\n\nis_current\x18\x02 \x01(\x08\x12\x0f\n\x07user_id\x18\x03 \x01(\x03\x12\x10\n\x08\x65vent_id\x18\x04 \x01(\x03\x12\x0f\n\x07page_id\x18\x05 \x01(\x03\x12\x0b\n\x03url\x18\x06 \x01(\t\"\xbe\x01\n\nUserUpload\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x10\n\x08\x66ilename\x18\x02 \x01(\t\x12\x10\n\x08\x66ull_url\x18\x03 \x01(\t\x12\x15\n\rthumbnail_url\x18\x04 \x01(\t\x12\x0e\n\x06\x63redit\x18\x05 \x01(\t\x12+\n\x07\x63reated\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x04uses\x18\x07 \x03(\x0b\x32\x1d.org.couchers.admin.UploadUse\"^\n\x12ListUserUploadsRes\x12/\n\x07uploads\x18\x01 \x03(\x0b\x32\x1e.org.couchers.admin.UserUpload\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x90\x03\n\nOTAPackage\x12\x16\n\x0eota_package_id\x18\x01 \x01(\x03\x12+\n\x07\x63reated\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x17\n\x0f\x63reator_user_id\x18\x03 \x01(\x03\x12\x31\n\x08platform\x18\x04 \x01(\x0e\x32\x1f.org.couchers.admin.OTAPlatform\x12\x13\n\x0b\x66ingerprint\x18\x05 \x01(\t\x12\x0f\n\x07version\x18\x06 \x01(\t\x12\x37\n\x13manifest_created_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0bmanifest_id\x18\x08 \x01(\t\x12\x0e\n\x06\x62\x61nned\x18\t \x01(\x08\x12-\n\tbanned_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x19\n\x11\x62\x61nned_by_user_id\x18\x0b \x01(\x03\x12\x15\n\rbanned_reason\x18\x0c \x01(\t\x12\x0c\n\x04live\x18\r \x01(\x08\"Y\n\x13\x43reateOTAPackageReq\x12\x31\n\x08platform\x18\x01 \x01(\x0e\x32\x1f.org.couchers.admin.OTAPlatform\x12\x0f\n\x07version\x18\x02 \x01(\t\"t\n\x12ListOTAPackagesReq\x12\x31\n\x08platform\x18\x01 \x01(\x0e\x32\x1f.org.couchers.admin.OTAPlatform\x12\x13\n\x0b\x66ingerprint\x18\x02 \x01(\t\x12\x16\n\x0einclude_banned\x18\x03 \x01(\x08\"F\n\x12ListOTAPackagesRes\x12\x30\n\x08packages\x18\x01 \x03(\x0b\x32\x1e.org.couchers.admin.OTAPackage\":\n\x10\x42\x61nOTAPackageReq\x12\x16\n\x0eota_package_id\x18\x01 \x01(\x03\x12\x0e\n\x06reason\x18\x02 \x01(\t*\xae\x01\n\x10\x41\x64minActionLevel\x12\"\n\x1e\x41\x44MIN_ACTION_LEVEL_UNSPECIFIED\x10\x00\x12\x1c\n\x18\x41\x44MIN_ACTION_LEVEL_TRACE\x10\x04\x12\x1c\n\x18\x41\x44MIN_ACTION_LEVEL_DEBUG\x10\x01\x12\x1d\n\x19\x41\x44MIN_ACTION_LEVEL_NORMAL\x10\x02\x12\x1b\n\x17\x41\x44MIN_ACTION_LEVEL_HIGH\x10\x03*\xd2\x01\n\x18NonvisibleUserAccessType\x12+\n\'NONVISIBLE_USER_ACCESS_TYPE_UNSPECIFIED\x10\x00\x12-\n)NONVISIBLE_USER_ACCESS_TYPE_LOGIN_ATTEMPT\x10\x01\x12,\n(NONVISIBLE_USER_ACCESS_TYPE_PROFILE_VIEW\x10\x02\x12,\n(NONVISIBLE_USER_ACCESS_TYPE_GHOST_SERVED\x10\x03*\xa5\x01\n\x13NonvisibleUserState\x12%\n!NONVISIBLE_USER_STATE_UNSPECIFIED\x10\x00\x12 \n\x1cNONVISIBLE_USER_STATE_BANNED\x10\x01\x12\"\n\x1eNONVISIBLE_USER_STATE_SHADOWED\x10\x02\x12!\n\x1dNONVISIBLE_USER_STATE_DELETED\x10\x03*\xc2\x01\n\rUploadUseType\x12\x1f\n\x1bUPLOAD_USE_TYPE_UNSPECIFIED\x10\x00\x12)\n%UPLOAD_USE_TYPE_PROFILE_GALLERY_PHOTO\x10\x01\x12\x30\n,UPLOAD_USE_TYPE_PROFILE_GALLERY_PHOTO_AVATAR\x10\x02\x12\x19\n\x15UPLOAD_USE_TYPE_EVENT\x10\x03\x12\x18\n\x14UPLOAD_USE_TYPE_PAGE\x10\x04*[\n\x0bOTAPlatform\x12\x1c\n\x18OTA_PLATFORM_UNSPECIFIED\x10\x00\x12\x14\n\x10OTA_PLATFORM_IOS\x10\x01\x12\x18\n\x14OTA_PLATFORM_ANDROID\x10\x02\x32\xe2#\n\x05\x41\x64min\x12Z\n\x0eGetUserDetails\x12%.org.couchers.admin.GetUserDetailsReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12H\n\x07GetUser\x12\x1e.org.couchers.admin.GetUserReq\x1a\x1b.org.couchers.api.core.User\"\x00\x12W\n\x0bSearchUsers\x12\".org.couchers.admin.SearchUsersReq\x1a\".org.couchers.admin.SearchUsersRes\"\x00\x12^\n\x10\x43hangeUserGender\x12\'.org.couchers.admin.ChangeUserGenderReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12\x64\n\x13\x43hangeUserBirthdate\x12*.org.couchers.admin.ChangeUserBirthdateReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12N\n\x08\x41\x64\x64\x42\x61\x64ge\x12\x1f.org.couchers.admin.AddBadgeReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12T\n\x0bRemoveBadge\x12\".org.couchers.admin.RemoveBadgeReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12x\n\x1dSetPassportSexGenderException\x12\x34.org.couchers.admin.SetPassportSexGenderExceptionReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12L\n\x07\x42\x61nUser\x12\x1e.org.couchers.admin.BanUserReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12P\n\tUnbanUser\x12 .org.couchers.admin.UnbanUserReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12R\n\nShadowUser\x12!.org.couchers.admin.ShadowUserReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12V\n\x0cUnshadowUser\x12#.org.couchers.admin.UnshadowUserReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12V\n\x0c\x41\x64\x64\x41\x64minNote\x12#.org.couchers.admin.AddAdminNoteReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12\x66\n\x10GetContentReport\x12\'.org.couchers.admin.GetContentReportReq\x1a\'.org.couchers.admin.GetContentReportRes\"\x00\x12\x84\x01\n\x1aGetContentReportsForAuthor\x12\x31.org.couchers.admin.GetContentReportsForAuthorReq\x1a\x31.org.couchers.admin.GetContentReportsForAuthorRes\"\x00\x12T\n\x0bSendModNote\x12\".org.couchers.admin.SendModNoteReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12t\n\x1bMarkUserNeedsLocationUpdate\x12\x32.org.couchers.admin.MarkUserNeedsLocationUpdateReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12R\n\nDeleteUser\x12!.org.couchers.admin.DeleteUserReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12\x62\n\x12RecoverDeletedUser\x12).org.couchers.admin.RecoverDeletedUserReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12Z\n\x0c\x43reateApiKey\x12#.org.couchers.admin.CreateApiKeyReq\x1a#.org.couchers.admin.CreateApiKeyRes\"\x00\x12N\n\x08GetChats\x12\x1f.org.couchers.admin.GetChatsReq\x1a\x1f.org.couchers.admin.GetChatsRes\"\x00\x12K\n\x0b\x44\x65leteEvent\x12\".org.couchers.admin.DeleteEventReq\x1a\x16.google.protobuf.Empty\"\x00\x12W\n\x0bListUserIds\x12\".org.couchers.admin.ListUserIdsReq\x1a\".org.couchers.admin.ListUserIdsRes\"\x00\x12W\n\x11\x45\x64itReferenceText\x12(.org.couchers.admin.EditReferenceTextReq\x1a\x16.google.protobuf.Empty\"\x00\x12S\n\x0f\x44\x65leteReference\x12&.org.couchers.admin.DeleteReferenceReq\x1a\x16.google.protobuf.Empty\"\x00\x12i\n\x11GetUserReferences\x12(.org.couchers.admin.GetUserReferencesReq\x1a(.org.couchers.admin.GetUserReferencesRes\"\x00\x12i\n\x11GetFriendRequests\x12(.org.couchers.admin.GetFriendRequestsReq\x1a(.org.couchers.admin.GetFriendRequestsRes\"\x00\x12\x84\x01\n\x1aGetNonvisibleUserAccessLog\x12\x31.org.couchers.admin.GetNonvisibleUserAccessLogReq\x1a\x31.org.couchers.admin.GetNonvisibleUserAccessLogRes\"\x00\x12Q\n\x0e\x45\x64itDiscussion\x12%.org.couchers.admin.EditDiscussionReq\x1a\x16.google.protobuf.Empty\"\x00\x12Z\n\x10\x44\x65leteDiscussion\x12,.org.couchers.admin.AdminDeleteDiscussionReq\x1a\x16.google.protobuf.Empty\"\x00\x12G\n\tEditReply\x12 .org.couchers.admin.EditReplyReq\x1a\x16.google.protobuf.Empty\"\x00\x12\x8a\x01\n\x1c\x41\x64\x64UsersToModerationUserList\x12\x33.org.couchers.admin.AddUsersToModerationUserListReq\x1a\x33.org.couchers.admin.AddUsersToModerationUserListRes\"\x00\x12u\n RemoveUserFromModerationUserList\x12\x37.org.couchers.admin.RemoveUserFromModerationUserListReq\x1a\x16.google.protobuf.Empty\"\x00\x12{\n\x17ListModerationUserLists\x12..org.couchers.admin.ListModerationUserListsReq\x1a..org.couchers.admin.ListModerationUserListsRes\"\x00\x12\x81\x01\n\x19\x43reateAccountDeletionLink\x12\x30.org.couchers.admin.CreateAccountDeletionLinkReq\x1a\x30.org.couchers.admin.CreateAccountDeletionLinkRes\"\x00\x12W\n\x0b\x41\x63\x63\x65ssStats\x12\".org.couchers.admin.AccessStatsReq\x1a\".org.couchers.admin.AccessStatsRes\"\x00\x12Z\n\x0eSetLastDonated\x12%.org.couchers.admin.SetLastDonatedReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12[\n\x0e\x43reateAdminTag\x12%.org.couchers.admin.CreateAdminTagReq\x1a .org.couchers.admin.AdminTagInfo\"\x00\x12]\n\rListAdminTags\x12$.org.couchers.admin.ListAdminTagsReq\x1a$.org.couchers.admin.ListAdminTagsRes\"\x00\x12`\n\x11\x41\x64\x64\x41\x64minTagToUser\x12(.org.couchers.admin.AddAdminTagToUserReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12j\n\x16RemoveAdminTagFromUser\x12-.org.couchers.admin.RemoveAdminTagFromUserReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12T\n\x0bSetModScore\x12\".org.couchers.admin.SetModScoreReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12\x66\n\x10ListAdminActions\x12\'.org.couchers.admin.ListAdminActionsReq\x1a\'.org.couchers.admin.ListAdminActionsRes\"\x00\x12\x63\n\x0fListUserUploads\x12&.org.couchers.admin.ListUserUploadsReq\x1a&.org.couchers.admin.ListUserUploadsRes\"\x00\x12]\n\x10\x43reateOTAPackage\x12\'.org.couchers.admin.CreateOTAPackageReq\x1a\x1e.org.couchers.admin.OTAPackage\"\x00\x12\x63\n\x0fListOTAPackages\x12&.org.couchers.admin.ListOTAPackagesReq\x1a&.org.couchers.admin.ListOTAPackagesRes\"\x00\x12W\n\rBanOTAPackage\x12$.org.couchers.admin.BanOTAPackageReq\x1a\x1e.org.couchers.admin.OTAPackage\"\x00\x1a\x04\x88\xb5\x18\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_ADMIN']._loaded_options = None
  _globals['_ADMIN']._serialized_options = b'\210\265\030\004'
  _globals['_ADMINACTIONLEVEL']._serialized_start=9552
  _globals['_ADMINACTIONLEVEL']._serialized_end=9726
  _globals['_NONVISIBLEUSERACCESSTYPE']._serialized_start=9729
  _globals['_NONVISIBLEUSERACCESSTYPE']._serialized_end=9939
  _globals['_NONVISIBLEUSERSTATE']._serialized_start=9942
  _globals['_NONVISIBLEUSERSTATE']._serialized_end=10107
  _globals['_UPLOADUSETYPE']._serialized_start=10110
  _globals['_UPLOADUSETYPE']._serialized_end=10304
  _globals['_OTAPLATFORM']._serialized_start=10306
  _globals['_OTAPLATFORM']._serialized_end=10397
  _globals['_ADMINACTIONLOG']._serialized_start=160
  _globals['_ADMINACTIONLOG']._serialized_end=457
  _globals['_ADMINTAGINFO']._serialized_start=459
  _globals['_ADMINTAGINFO']._serialized_end=508
  _globals['_USERDETAILS']._serialized_start=511
  _globals['_USERDETAILS']._serialized_end=1215
  _globals['_GETUSERDETAILSREQ']._serialized_start=1217
  _globals['_GETUSERDETAILSREQ']._serialized_end=1250
  _globals['_GETUSERREQ']._serialized_start=1252
  _globals['_GETUSERREQ']._serialized_end=1278
  _globals['_SEARCHUSERSREQ']._serialized_start=1281
  _globals['_SEARCHUSERSREQ']._serialized_end=1874
  _globals['_SEARCHUSERSRES']._serialized_start=1876
  _globals['_SEARCHUSERSRES']._serialized_end=1965
  _globals['_CHANGEUSERGENDERREQ']._serialized_start=1967
  _globals['_CHANGEUSERGENDERREQ']._serialized_end=2018
  _globals['_CHANGEUSERBIRTHDATEREQ']._serialized_start=2020
  _globals['_CHANGEUSERBIRTHDATEREQ']._serialized_end=2077
  _globals['_ADDBADGEREQ']._serialized_start=2079
  _globals['_ADDBADGEREQ']._serialized_end=2124
  _globals['_REMOVEBADGEREQ']._serialized_start=2126
  _globals['_REMOVEBADGEREQ']._serialized_end=2174
  _globals['_SETPASSPORTSEXGENDEREXCEPTIONREQ']._serialized_start=2176
  _globals['_SETPASSPORTSEXGENDEREXCEPTIONREQ']._serialized_end=2263
  _globals['_BANUSERREQ']._serialized_start=2265
  _globals['_BANUSERREQ']._serialized_end=2311
  _globals['_UNBANUSERREQ']._serialized_start=2313
  _globals['_UNBANUSERREQ']._serialized_end=2361
  _globals['_SHADOWUSERREQ']._serialized_start=2363
  _globals['_SHADOWUSERREQ']._serialized_end=2412
  _globals['_UNSHADOWUSERREQ']._serialized_start=2414
  _globals['_UNSHADOWUSERREQ']._serialized_end=2465
  _globals['_ADDADMINNOTEREQ']._serialized_start=2467
  _globals['_ADDADMINNOTEREQ']._serialized_end=2585
  _globals['_CONTENTREPORT']._serialized_start=2588
  _globals['_CONTENTREPORT']._serialized_end=2815
  _globals['_GETCONTENTREPORTREQ']._serialized_start=2817
  _globals['_GETCONTENTREPORTREQ']._serialized_end=2865
  _globals['_GETCONTENTREPORTRES']._serialized_start=2867
  _globals['_GETCONTENTREPORTRES']._serialized_end=2947
  _globals['_GETCONTENTREPORTSFORAUTHORREQ']._serialized_start=2949
  _globals['_GETCONTENTREPORTSFORAUTHORREQ']._serialized_end=2994
  _globals['_GETCONTENTREPORTSFORAUTHORRES']._serialized_start=2996
  _globals['_GETCONTENTREPORTSFORAUTHORRES']._serialized_end=3087
  _globals['_SENDMODNOTEREQ']._serialized_start=3089
  _globals['_SENDMODNOTEREQ']._serialized_end=3180
  _globals['_MARKUSERNEEDSLOCATIONUPDATEREQ']._serialized_start=3182
  _globals['_MARKUSERNEEDSLOCATIONUPDATEREQ']._serialized_end=3228
  _globals['_DELETEUSERREQ']._serialized_start=3230
  _globals['_DELETEUSERREQ']._serialized_end=3259
  _globals['_RECOVERDELETEDUSERREQ']._serialized_start=3261
  _globals['_RECOVERDELETEDUSERREQ']._serialized_end=3298
  _globals['_CREATEAPIKEYREQ']._serialized_start=3300
  _globals['_CREATEAPIKEYREQ']._serialized_end=3331
  _globals['_CREATEAPIKEYRES']._serialized_start=3333
  _globals['_CREATEAPIKEYRES']._serialized_end=3350
  _globals['_GETCHATSREQ']._serialized_start=3352
  _globals['_GETCHATSREQ']._serialized_end=3379
  _globals['_CHATUSERINFO']._serialized_start=3381
  _globals['_CHATUSERINFO']._serialized_end=3479
  _globals['_CHATMESSAGE']._serialized_start=3482
  _globals['_CHATMESSAGE']._serialized_end=3729
  _globals['_GROUPCHATMEMBER']._serialized_start=3732
  _globals['_GROUPCHATMEMBER']._serialized_end=3897
  _globals['_ADMINGROUPCHAT']._serialized_start=3900
  _globals['_ADMINGROUPCHAT']._serialized_end=4125
  _globals['_ADMINHOSTREQUEST']._serialized_start=4128
  _globals['_ADMINHOSTREQUEST']._serialized_end=4417
  _globals['_GETCHATSRES']._serialized_start=4420
  _globals['_GETCHATSRES']._serialized_end=4599
  _globals['_DELETEEVENTREQ']._serialized_start=4601
  _globals['_DELETEEVENTREQ']._serialized_end=4635
  _globals['_LISTUSERIDSREQ']._serialized_start=4638
  _globals['_LISTUSERIDSREQ']._serialized_end=4787
  _globals['_LISTUSERIDSRES']._serialized_start=4789
  _globals['_LISTUSERIDSRES']._serialized_end=4848
  _globals['_EDITREFERENCETEXTREQ']._serialized_start=4850
  _globals['_EDITREFERENCETEXTREQ']._serialized_end=4912
  _globals['_DELETEREFERENCEREQ']._serialized_start=4914
  _globals['_DELETEREFERENCEREQ']._serialized_end=4956
  _globals['_GETUSERREFERENCESREQ']._serialized_start=4958
  _globals['_GETUSERREFERENCESREQ']._serialized_end=4994
  _globals['_ADMINREFERENCE']._serialized_start=4997
  _globals['_ADMINREFERENCE']._serialized_end=5263
  _globals['_GETUSERREFERENCESRES']._serialized_start=5266
  _globals['_GETUSERREFERENCESRES']._serialized_end=5408
  _globals['_GETFRIENDREQUESTSREQ']._serialized_start=5410
  _globals['_GETFRIENDREQUESTSREQ']._serialized_end=5446
  _globals['_ADMINFRIENDREQUEST']._serialized_start=5449
  _globals['_ADMINFRIENDREQUEST']._serialized_end=5746
  _globals['_GETFRIENDREQUESTSRES']._serialized_start=5749
  _globals['_GETFRIENDREQUESTSRES']._serialized_end=5883
  _globals['_GETNONVISIBLEUSERACCESSLOGREQ']._serialized_start=5885
  _globals['_GETNONVISIBLEUSERACCESSLOGREQ']._serialized_end=5930
  _globals['_NONVISIBLEUSERACCESSLOGENTRY']._serialized_start=5933
  _globals['_NONVISIBLEUSERACCESSLOGENTRY']._serialized_end=6289
  _globals['_GETNONVISIBLEUSERACCESSLOGRES']._serialized_start=6291
  _globals['_GETNONVISIBLEUSERACCESSLOGRES']._serialized_end=6389
  _globals['_EDITDISCUSSIONREQ']._serialized_start=6391
  _globals['_EDITDISCUSSIONREQ']._serialized_end=6473
  _globals['_ADMINDELETEDISCUSSIONREQ']._serialized_start=6475
  _globals['_ADMINDELETEDISCUSSIONREQ']._serialized_end=6524
  _globals['_EDITREPLYREQ']._serialized_start=6526
  _globals['_EDITREPLYREQ']._serialized_end=6579
  _globals['_ADDUSERSTOMODERATIONUSERLISTREQ']._serialized_start=6581
  _globals['_ADDUSERSTOMODERATIONUSERLISTREQ']._serialized_end=6657
  _globals['_LISTMODERATIONUSERLISTSREQ']._serialized_start=6659
  _globals['_LISTMODERATIONUSERLISTSREQ']._serialized_end=6701
  _globals['_MODERATIONLIST']._serialized_start=6703
  _globals['_MODERATIONLIST']._serialized_end=6815
  _globals['_LISTMODERATIONUSERLISTSRES']._serialized_start=6817
  _globals['_LISTMODERATIONUSERLISTSRES']._serialized_end=6907
  _globals['_ADDUSERSTOMODERATIONUSERLISTRES']._serialized_start=6909
  _globals['_ADDUSERSTOMODERATIONUSERLISTRES']._serialized_end=6970
  _globals['_REMOVEUSERFROMMODERATIONUSERLISTREQ']._serialized_start=6972
  _globals['_REMOVEUSERFROMMODERATIONUSERLISTREQ']._serialized_end=7051
  _globals['_CREATEACCOUNTDELETIONLINKREQ']._serialized_start=7053
  _globals['_CREATEACCOUNTDELETIONLINKREQ']._serialized_end=7118
  _globals['_CREATEACCOUNTDELETIONLINKRES']._serialized_start=7120
  _globals['_CREATEACCOUNTDELETIONLINKRES']._serialized_end=7188
  _globals['_ACCESSSTATSREQ']._serialized_start=7190
  _globals['_ACCESSSTATSREQ']._serialized_end=7314
  _globals['_ACCESSSTAT']._serialized_start=7317
  _globals['_ACCESSSTAT']._serialized_end=7647
  _globals['_ACCESSSTATSRES']._serialized_start=7649
  _globals['_ACCESSSTATSRES']._serialized_end=7712
  _globals['_SETLASTDONATEDREQ']._serialized_start=7714
  _globals['_SETLASTDONATEDREQ']._serialized_end=7797
  _globals['_CREATEADMINTAGREQ']._serialized_start=7799
  _globals['_CREATEADMINTAGREQ']._serialized_end=7831
  _globals['_LISTADMINTAGSREQ']._serialized_start=7833
  _globals['_LISTADMINTAGSREQ']._serialized_end=7851
  _globals['_LISTADMINTAGSRES']._serialized_start=7853
  _globals['_LISTADMINTAGSRES']._serialized_end=7919
  _globals['_ADDADMINTAGTOUSERREQ']._serialized_start=7921
  _globals['_ADDADMINTAGTOUSERREQ']._serialized_end=7970
  _globals['_REMOVEADMINTAGFROMUSERREQ']._serialized_start=7972
  _globals['_REMOVEADMINTAGFROMUSERREQ']._serialized_end=8026
  _globals['_SETMODSCOREREQ']._serialized_start=8028
  _globals['_SETMODSCOREREQ']._serialized_end=8077
  _globals['_LISTADMINACTIONSREQ']._serialized_start=8079
  _globals['_LISTADMINACTIONSREQ']._serialized_end=8186
  _globals['_LISTADMINACTIONSRES']._serialized_start=8188
  _globals['_LISTADMINACTIONSRES']._serialized_end=8293
  _globals['_LISTUSERUPLOADSREQ']._serialized_start=8295
  _globals['_LISTUSERUPLOADSREQ']._serialized_end=8368
  _globals['_UPLOADUSE']._serialized_start=8371
  _globals['_UPLOADUSE']._serialized_end=8516
  _globals['_USERUPLOAD']._serialized_start=8519
  _globals['_USERUPLOAD']._serialized_end=8709
  _globals['_LISTUSERUPLOADSRES']._serialized_start=8711
  _globals['_LISTUSERUPLOADSRES']._serialized_end=8805
  _globals['_OTAPACKAGE']._serialized_start=8808
  _globals['_OTAPACKAGE']._serialized_end=9208
  _globals['_CREATEOTAPACKAGEREQ']._serialized_start=9210
  _globals['_CREATEOTAPACKAGEREQ']._serialized_end=9299
  _globals['_LISTOTAPACKAGESREQ']._serialized_start=9301
  _globals['_LISTOTAPACKAGESREQ']._serialized_end=9417
  _globals['_LISTOTAPACKAGESRES']._serialized_start=9419
  _globals['_LISTOTAPACKAGESRES']._serialized_end=9489
  _globals['_BANOTAPACKAGEREQ']._serialized_start=9491
  _globals['_BANOTAPACKAGEREQ']._serialized_end=9549
  _globals['_ADMIN']._serialized_start=10400
  _globals['_ADMIN']._serialized_end=14978
# @@protoc_insertion_point(module_scope)
