# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: donations.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from . import annotations_pb2 as annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0f\x64onations.proto\x12\x1aorg.couchers.api.donations\x1a\x1bgoogle/protobuf/empty.proto\x1a\x11\x61nnotations.proto\"H\n\x13InitiateDonationReq\x12\x0e\n\x06\x61mount\x18\x01 \x01(\r\x12\x11\n\trecurring\x18\x02 \x01(\x08\x12\x0e\n\x06source\x18\x03 \x01(\t\"V\n\x13InitiateDonationRes\x12\"\n\x1astripe_checkout_session_id\x18\x01 \x01(\t\x12\x1b\n\x13stripe_checkout_url\x18\x02 \x01(\t\"5\n\x18GetDonationPortalLinkRes\x12\x19\n\x11stripe_portal_url\x18\x01 \x01(\t2\xf2\x01\n\tDonations\x12v\n\x10InitiateDonation\x12/.org.couchers.api.donations.InitiateDonationReq\x1a/.org.couchers.api.donations.InitiateDonationRes\"\x00\x12g\n\x15GetDonationPortalLink\x12\x16.google.protobuf.Empty\x1a\x34.org.couchers.api.donations.GetDonationPortalLinkRes\"\x00\x1a\x04\x88\xb5\x18\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'donations_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_DONATIONS']._loaded_options = None
  _globals['_DONATIONS']._serialized_options = b'\210\265\030\003'
  _globals['_INITIATEDONATIONREQ']._serialized_start=95
  _globals['_INITIATEDONATIONREQ']._serialized_end=167
  _globals['_INITIATEDONATIONRES']._serialized_start=169
  _globals['_INITIATEDONATIONRES']._serialized_end=255
  _globals['_GETDONATIONPORTALLINKRES']._serialized_start=257
  _globals['_GETDONATIONPORTALLINKRES']._serialized_end=310
  _globals['_DONATIONS']._serialized_start=313
  _globals['_DONATIONS']._serialized_end=555
# @@protoc_insertion_point(module_scope)
