"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import account_pb2
import builtins
import discussions_pb2
import events_pb2
import google.protobuf.descriptor
import google.protobuf.message
import requests_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetDashboardV2Req(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___GetDashboardV2Req: typing_extensions.TypeAlias = GetDashboardV2Req

@typing.final
class GetDashboardV2Res(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REMINDERS_FIELD_NUMBER: builtins.int
    SURFING_FIELD_NUMBER: builtins.int
    HOSTING_FIELD_NUMBER: builtins.int
    MY_EVENTS_FIELD_NUMBER: builtins.int
    COMMUNITY_EVENTS_FIELD_NUMBER: builtins.int
    DISCUSSIONS_FIELD_NUMBER: builtins.int
    @property
    def reminders(self) -> account_pb2.GetRemindersRes: ...
    @property
    def surfing(self) -> requests_pb2.ListHostRequestsRes: ...
    @property
    def hosting(self) -> requests_pb2.ListHostRequestsRes: ...
    @property
    def my_events(self) -> events_pb2.ListMyEventsRes: ...
    @property
    def community_events(self) -> events_pb2.ListMyEventsRes: ...
    @property
    def discussions(self) -> discussions_pb2.ListMyCommunitiesDiscussionsRes: ...
    def __init__(
        self,
        *,
        reminders: account_pb2.GetRemindersRes | None = ...,
        surfing: requests_pb2.ListHostRequestsRes | None = ...,
        hosting: requests_pb2.ListHostRequestsRes | None = ...,
        my_events: events_pb2.ListMyEventsRes | None = ...,
        community_events: events_pb2.ListMyEventsRes | None = ...,
        discussions: discussions_pb2.ListMyCommunitiesDiscussionsRes | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["community_events", b"community_events", "discussions", b"discussions", "hosting", b"hosting", "my_events", b"my_events", "reminders", b"reminders", "surfing", b"surfing"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["community_events", b"community_events", "discussions", b"discussions", "hosting", b"hosting", "my_events", b"my_events", "reminders", b"reminders", "surfing", b"surfing"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___GetDashboardV2Res: typing_extensions.TypeAlias = GetDashboardV2Res
