# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: conversations.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from . import annotations_pb2 as annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x63onversations.proto\x12\x1eorg.couchers.api.conversations\x1a\x1egoogle/protobuf/duration.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x11\x61nnotations.proto\"\"\n\x12MessageContentText\x12\x0c\n\x04text\x18\x01 \x01(\t\"\x1b\n\x19MessageContentChatCreated\"\x1a\n\x18MessageContentChatEdited\"3\n\x19MessageContentUserInvited\x12\x16\n\x0etarget_user_id\x18\x01 \x01(\x04\"\x18\n\x16MessageContentUserLeft\"5\n\x1bMessageContentUserMadeAdmin\x12\x16\n\x0etarget_user_id\x18\x01 \x01(\x04\"8\n\x1eMessageContentUserRemovedAdmin\x12\x16\n\x0etarget_user_id\x18\x01 \x01(\x04\"3\n\x19MessageContentUserRemoved\x12\x16\n\x0etarget_user_id\x18\x01 \x01(\x04\"k\n&MessageContentHostRequestStatusChanged\x12\x41\n\x06status\x18\x01 \x01(\x0e\x32\x31.org.couchers.api.conversations.HostRequestStatus\"\xf5\x06\n\x07Message\x12\x12\n\nmessage_id\x18\x01 \x01(\x04\x12\x16\n\x0e\x61uthor_user_id\x18\x02 \x01(\x04\x12(\n\x04time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x42\n\x04text\x18\x04 \x01(\x0b\x32\x32.org.couchers.api.conversations.MessageContentTextH\x00\x12Q\n\x0c\x63hat_created\x18\x05 \x01(\x0b\x32\x39.org.couchers.api.conversations.MessageContentChatCreatedH\x00\x12O\n\x0b\x63hat_edited\x18\x06 \x01(\x0b\x32\x38.org.couchers.api.conversations.MessageContentChatEditedH\x00\x12Q\n\x0cuser_invited\x18\x07 \x01(\x0b\x32\x39.org.couchers.api.conversations.MessageContentUserInvitedH\x00\x12K\n\tuser_left\x18\x08 \x01(\x0b\x32\x36.org.couchers.api.conversations.MessageContentUserLeftH\x00\x12V\n\x0fuser_made_admin\x18\t \x01(\x0b\x32;.org.couchers.api.conversations.MessageContentUserMadeAdminH\x00\x12\\\n\x12user_removed_admin\x18\n \x01(\x0b\x32>.org.couchers.api.conversations.MessageContentUserRemovedAdminH\x00\x12m\n\x1bhost_request_status_changed\x18\x0b \x01(\x0b\x32\x46.org.couchers.api.conversations.MessageContentHostRequestStatusChangedH\x00\x12\\\n\x17group_chat_user_removed\x18\x0c \x01(\x0b\x32\x39.org.couchers.api.conversations.MessageContentUserRemovedH\x00\x42\t\n\x07\x63ontent\"J\n\x08MuteInfo\x12\r\n\x05muted\x18\x01 \x01(\x08\x12/\n\x0bmuted_until\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x9e\x03\n\tGroupChat\x12\x15\n\rgroup_chat_id\x18\x01 \x01(\x04\x12\r\n\x05title\x18\x02 \x01(\t\x12\x17\n\x0fmember_user_ids\x18\x03 \x03(\x04\x12\x16\n\x0e\x61\x64min_user_ids\x18\x04 \x03(\x04\x12\x1a\n\x12only_admins_invite\x18\x05 \x01(\x08\x12\r\n\x05is_dm\x18\x06 \x01(\x08\x12+\n\x07\x63reated\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1c\n\x14unseen_message_count\x18\x08 \x01(\r\x12\x1c\n\x14last_seen_message_id\x18\t \x01(\x04\x12?\n\x0elatest_message\x18\n \x01(\x0b\x32\'.org.couchers.api.conversations.Message\x12;\n\tmute_info\x18\x0b \x01(\x0b\x32(.org.couchers.api.conversations.MuteInfo\x12\x13\n\x0b\x63\x61n_message\x18\x0c \x01(\x08\x12\x13\n\x0bis_archived\x18\r \x01(\x08\"(\n\x0fGetGroupChatReq\x12\x15\n\rgroup_chat_id\x18\x01 \x01(\x04\"j\n\x11ListGroupChatsReq\x12\x17\n\x0flast_message_id\x18\x01 \x01(\x04\x12\x0e\n\x06number\x18\x02 \x01(\r\x12\x1a\n\ronly_archived\x18\x03 \x01(\x08H\x00\x88\x01\x01\x42\x10\n\x0e_only_archived\"}\n\x11ListGroupChatsRes\x12>\n\x0bgroup_chats\x18\x01 \x03(\x0b\x32).org.couchers.api.conversations.GroupChat\x12\x17\n\x0flast_message_id\x18\x02 \x01(\x04\x12\x0f\n\x07no_more\x18\x03 \x01(\x08\"*\n\rGetUpdatesReq\x12\x19\n\x11newest_message_id\x18\x01 \x01(\x04\"&\n\x13GetDirectMessageReq\x12\x0f\n\x07user_id\x18\x01 \x01(\x04\"Y\n\x06Update\x12\x15\n\rgroup_chat_id\x18\x01 \x01(\x04\x12\x38\n\x07message\x18\x02 \x01(\x0b\x32\'.org.couchers.api.conversations.Message\"Y\n\rGetUpdatesRes\x12\x37\n\x07updates\x18\x01 \x03(\x0b\x32&.org.couchers.api.conversations.Update\x12\x0f\n\x07no_more\x18\x02 \x01(\x08\"n\n\x17GetGroupChatMessagesReq\x12\x15\n\rgroup_chat_id\x18\x01 \x01(\x04\x12\x17\n\x0flast_message_id\x18\x02 \x01(\x04\x12\x0e\n\x06number\x18\x03 \x01(\r\x12\x13\n\x0bonly_unseen\x18\x04 \x01(\x08\"~\n\x17GetGroupChatMessagesRes\x12\x39\n\x08messages\x18\x01 \x03(\x0b\x32\'.org.couchers.api.conversations.Message\x12\x17\n\x0flast_message_id\x18\x02 \x01(\x04\x12\x0f\n\x07no_more\x18\x03 \x01(\x08\"O\n\x18MarkLastSeenGroupChatReq\x12\x15\n\rgroup_chat_id\x18\x01 \x01(\x04\x12\x1c\n\x14last_seen_message_id\x18\x02 \x01(\x04\"\x8d\x01\n\x10MuteGroupChatReq\x12\x15\n\rgroup_chat_id\x18\x01 \x01(\x04\x12\x10\n\x06unmute\x18\x02 \x01(\x08H\x00\x12\x11\n\x07\x66orever\x18\x03 \x01(\x08H\x00\x12\x31\n\x0c\x66or_duration\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationH\x00\x42\n\n\x08\x64uration\"J\n\x1cSetGroupChatArchiveStatusReq\x12\x15\n\rgroup_chat_id\x18\x01 \x01(\x04\x12\x13\n\x0bis_archived\x18\x02 \x01(\x08\"J\n\x1cSetGroupChatArchiveStatusRes\x12\x15\n\rgroup_chat_id\x18\x01 \x01(\x04\x12\x13\n\x0bis_archived\x18\x02 \x01(\x08\"]\n\x12\x43reateGroupChatReq\x12+\n\x05title\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x1a\n\x12recipient_user_ids\x18\x02 \x03(\x04\"\x8e\x01\n\x10\x45\x64itGroupChatReq\x12\x15\n\rgroup_chat_id\x18\x01 \x01(\x04\x12+\n\x05title\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x36\n\x12only_admins_invite\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\">\n\x14InviteToGroupChatReq\x12\x15\n\rgroup_chat_id\x18\x01 \x01(\x04\x12\x0f\n\x07user_id\x18\x02 \x01(\x04\"?\n\x15MakeGroupChatAdminReq\x12\x15\n\rgroup_chat_id\x18\x01 \x01(\x04\x12\x0f\n\x07user_id\x18\x02 \x01(\x04\"@\n\x16RemoveGroupChatUserReq\x12\x15\n\rgroup_chat_id\x18\x01 \x01(\x04\x12\x0f\n\x07user_id\x18\x02 \x01(\x04\"A\n\x17RemoveGroupChatAdminReq\x12\x15\n\rgroup_chat_id\x18\x01 \x01(\x04\x12\x0f\n\x07user_id\x18\x02 \x01(\x04\"5\n\x0eSendMessageReq\x12\x15\n\rgroup_chat_id\x18\x01 \x01(\x04\x12\x0c\n\x04text\x18\x02 \x01(\t\"?\n\x14SendDirectMessageReq\x12\x19\n\x11recipient_user_id\x18\x01 \x01(\x04\x12\x0c\n\x04text\x18\x02 \x01(\t\"-\n\x14SendDirectMessageRes\x12\x15\n\rgroup_chat_id\x18\x01 \x01(\x04\"*\n\x11LeaveGroupChatReq\x12\x15\n\rgroup_chat_id\x18\x01 \x01(\x04\"K\n\x11SearchMessagesReq\x12\r\n\x05query\x18\x01 \x01(\t\x12\x17\n\x0flast_message_id\x18\x02 \x01(\x04\x12\x0e\n\x06number\x18\x03 \x01(\r\"f\n\x13MessageSearchResult\x12\x15\n\rgroup_chat_id\x18\x01 \x01(\x04\x12\x38\n\x07message\x18\x02 \x01(\x0b\x32\'.org.couchers.api.conversations.Message\"\x83\x01\n\x11SearchMessagesRes\x12\x44\n\x07results\x18\x01 \x03(\x0b\x32\x33.org.couchers.api.conversations.MessageSearchResult\x12\x17\n\x0flast_message_id\x18\x02 \x01(\x04\x12\x0f\n\x07no_more\x18\x03 \x01(\x08*\xbe\x01\n\x11HostRequestStatus\x12\x1f\n\x1bHOST_REQUEST_STATUS_PENDING\x10\x00\x12 \n\x1cHOST_REQUEST_STATUS_ACCEPTED\x10\x01\x12 \n\x1cHOST_REQUEST_STATUS_REJECTED\x10\x02\x12!\n\x1dHOST_REQUEST_STATUS_CONFIRMED\x10\x03\x12!\n\x1dHOST_REQUEST_STATUS_CANCELLED\x10\x04\x32\xfb\x0f\n\rConversations\x12x\n\x0eListGroupChats\x12\x31.org.couchers.api.conversations.ListGroupChatsReq\x1a\x31.org.couchers.api.conversations.ListGroupChatsRes\"\x00\x12l\n\x0cGetGroupChat\x12/.org.couchers.api.conversations.GetGroupChatReq\x1a).org.couchers.api.conversations.GroupChat\"\x00\x12t\n\x10GetDirectMessage\x12\x33.org.couchers.api.conversations.GetDirectMessageReq\x1a).org.couchers.api.conversations.GroupChat\"\x00\x12l\n\nGetUpdates\x12-.org.couchers.api.conversations.GetUpdatesReq\x1a-.org.couchers.api.conversations.GetUpdatesRes\"\x00\x12\x8a\x01\n\x14GetGroupChatMessages\x12\x37.org.couchers.api.conversations.GetGroupChatMessagesReq\x1a\x37.org.couchers.api.conversations.GetGroupChatMessagesRes\"\x00\x12k\n\x15MarkLastSeenGroupChat\x12\x38.org.couchers.api.conversations.MarkLastSeenGroupChatReq\x1a\x16.google.protobuf.Empty\"\x00\x12[\n\rMuteGroupChat\x12\x30.org.couchers.api.conversations.MuteGroupChatReq\x1a\x16.google.protobuf.Empty\"\x00\x12\x99\x01\n\x19SetGroupChatArchiveStatus\x12<.org.couchers.api.conversations.SetGroupChatArchiveStatusReq\x1a<.org.couchers.api.conversations.SetGroupChatArchiveStatusRes\"\x00\x12r\n\x0f\x43reateGroupChat\x12\x32.org.couchers.api.conversations.CreateGroupChatReq\x1a).org.couchers.api.conversations.GroupChat\"\x00\x12[\n\rEditGroupChat\x12\x30.org.couchers.api.conversations.EditGroupChatReq\x1a\x16.google.protobuf.Empty\"\x00\x12\x63\n\x11InviteToGroupChat\x12\x34.org.couchers.api.conversations.InviteToGroupChatReq\x1a\x16.google.protobuf.Empty\"\x00\x12\x65\n\x12MakeGroupChatAdmin\x12\x35.org.couchers.api.conversations.MakeGroupChatAdminReq\x1a\x16.google.protobuf.Empty\"\x00\x12g\n\x13RemoveGroupChatUser\x12\x36.org.couchers.api.conversations.RemoveGroupChatUserReq\x1a\x16.google.protobuf.Empty\"\x00\x12i\n\x14RemoveGroupChatAdmin\x12\x37.org.couchers.api.conversations.RemoveGroupChatAdminReq\x1a\x16.google.protobuf.Empty\"\x00\x12W\n\x0bSendMessage\x12..org.couchers.api.conversations.SendMessageReq\x1a\x16.google.protobuf.Empty\"\x00\x12\x81\x01\n\x11SendDirectMessage\x12\x34.org.couchers.api.conversations.SendDirectMessageReq\x1a\x34.org.couchers.api.conversations.SendDirectMessageRes\"\x00\x12]\n\x0eLeaveGroupChat\x12\x31.org.couchers.api.conversations.LeaveGroupChatReq\x1a\x16.google.protobuf.Empty\"\x00\x12x\n\x0eSearchMessages\x12\x31.org.couchers.api.conversations.SearchMessagesReq\x1a\x31.org.couchers.api.conversations.SearchMessagesRes\"\x00\x1a\x04\x88\xb5\x18\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'conversations_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_CONVERSATIONS']._loaded_options = None
  _globals['_CONVERSATIONS']._serialized_options = b'\210\265\030\003'
  _globals['_HOSTREQUESTSTATUS']._serialized_start=4217
  _globals['_HOSTREQUESTSTATUS']._serialized_end=4407
  _globals['_MESSAGECONTENTTEXT']._serialized_start=200
  _globals['_MESSAGECONTENTTEXT']._serialized_end=234
  _globals['_MESSAGECONTENTCHATCREATED']._serialized_start=236
  _globals['_MESSAGECONTENTCHATCREATED']._serialized_end=263
  _globals['_MESSAGECONTENTCHATEDITED']._serialized_start=265
  _globals['_MESSAGECONTENTCHATEDITED']._serialized_end=291
  _globals['_MESSAGECONTENTUSERINVITED']._serialized_start=293
  _globals['_MESSAGECONTENTUSERINVITED']._serialized_end=344
  _globals['_MESSAGECONTENTUSERLEFT']._serialized_start=346
  _globals['_MESSAGECONTENTUSERLEFT']._serialized_end=370
  _globals['_MESSAGECONTENTUSERMADEADMIN']._serialized_start=372
  _globals['_MESSAGECONTENTUSERMADEADMIN']._serialized_end=425
  _globals['_MESSAGECONTENTUSERREMOVEDADMIN']._serialized_start=427
  _globals['_MESSAGECONTENTUSERREMOVEDADMIN']._serialized_end=483
  _globals['_MESSAGECONTENTUSERREMOVED']._serialized_start=485
  _globals['_MESSAGECONTENTUSERREMOVED']._serialized_end=536
  _globals['_MESSAGECONTENTHOSTREQUESTSTATUSCHANGED']._serialized_start=538
  _globals['_MESSAGECONTENTHOSTREQUESTSTATUSCHANGED']._serialized_end=645
  _globals['_MESSAGE']._serialized_start=648
  _globals['_MESSAGE']._serialized_end=1533
  _globals['_MUTEINFO']._serialized_start=1535
  _globals['_MUTEINFO']._serialized_end=1609
  _globals['_GROUPCHAT']._serialized_start=1612
  _globals['_GROUPCHAT']._serialized_end=2026
  _globals['_GETGROUPCHATREQ']._serialized_start=2028
  _globals['_GETGROUPCHATREQ']._serialized_end=2068
  _globals['_LISTGROUPCHATSREQ']._serialized_start=2070
  _globals['_LISTGROUPCHATSREQ']._serialized_end=2176
  _globals['_LISTGROUPCHATSRES']._serialized_start=2178
  _globals['_LISTGROUPCHATSRES']._serialized_end=2303
  _globals['_GETUPDATESREQ']._serialized_start=2305
  _globals['_GETUPDATESREQ']._serialized_end=2347
  _globals['_GETDIRECTMESSAGEREQ']._serialized_start=2349
  _globals['_GETDIRECTMESSAGEREQ']._serialized_end=2387
  _globals['_UPDATE']._serialized_start=2389
  _globals['_UPDATE']._serialized_end=2478
  _globals['_GETUPDATESRES']._serialized_start=2480
  _globals['_GETUPDATESRES']._serialized_end=2569
  _globals['_GETGROUPCHATMESSAGESREQ']._serialized_start=2571
  _globals['_GETGROUPCHATMESSAGESREQ']._serialized_end=2681
  _globals['_GETGROUPCHATMESSAGESRES']._serialized_start=2683
  _globals['_GETGROUPCHATMESSAGESRES']._serialized_end=2809
  _globals['_MARKLASTSEENGROUPCHATREQ']._serialized_start=2811
  _globals['_MARKLASTSEENGROUPCHATREQ']._serialized_end=2890
  _globals['_MUTEGROUPCHATREQ']._serialized_start=2893
  _globals['_MUTEGROUPCHATREQ']._serialized_end=3034
  _globals['_SETGROUPCHATARCHIVESTATUSREQ']._serialized_start=3036
  _globals['_SETGROUPCHATARCHIVESTATUSREQ']._serialized_end=3110
  _globals['_SETGROUPCHATARCHIVESTATUSRES']._serialized_start=3112
  _globals['_SETGROUPCHATARCHIVESTATUSRES']._serialized_end=3186
  _globals['_CREATEGROUPCHATREQ']._serialized_start=3188
  _globals['_CREATEGROUPCHATREQ']._serialized_end=3281
  _globals['_EDITGROUPCHATREQ']._serialized_start=3284
  _globals['_EDITGROUPCHATREQ']._serialized_end=3426
  _globals['_INVITETOGROUPCHATREQ']._serialized_start=3428
  _globals['_INVITETOGROUPCHATREQ']._serialized_end=3490
  _globals['_MAKEGROUPCHATADMINREQ']._serialized_start=3492
  _globals['_MAKEGROUPCHATADMINREQ']._serialized_end=3555
  _globals['_REMOVEGROUPCHATUSERREQ']._serialized_start=3557
  _globals['_REMOVEGROUPCHATUSERREQ']._serialized_end=3621
  _globals['_REMOVEGROUPCHATADMINREQ']._serialized_start=3623
  _globals['_REMOVEGROUPCHATADMINREQ']._serialized_end=3688
  _globals['_SENDMESSAGEREQ']._serialized_start=3690
  _globals['_SENDMESSAGEREQ']._serialized_end=3743
  _globals['_SENDDIRECTMESSAGEREQ']._serialized_start=3745
  _globals['_SENDDIRECTMESSAGEREQ']._serialized_end=3808
  _globals['_SENDDIRECTMESSAGERES']._serialized_start=3810
  _globals['_SENDDIRECTMESSAGERES']._serialized_end=3855
  _globals['_LEAVEGROUPCHATREQ']._serialized_start=3857
  _globals['_LEAVEGROUPCHATREQ']._serialized_end=3899
  _globals['_SEARCHMESSAGESREQ']._serialized_start=3901
  _globals['_SEARCHMESSAGESREQ']._serialized_end=3976
  _globals['_MESSAGESEARCHRESULT']._serialized_start=3978
  _globals['_MESSAGESEARCHRESULT']._serialized_end=4080
  _globals['_SEARCHMESSAGESRES']._serialized_start=4083
  _globals['_SEARCHMESSAGESRES']._serialized_end=4214
  _globals['_CONVERSATIONS']._serialized_start=4410
  _globals['_CONVERSATIONS']._serialized_end=6453
# @@protoc_insertion_point(module_scope)
