from sqlalchemy import orm
from couchers.context import CouchersContext
"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import google.api.httpbody_pb2
import grpc
import grpc.aio
import typing


GRPC_GENERATED_VERSION: str
GRPC_VERSION: str

class IrisStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    Webhook: grpc.UnaryUnaryMultiCallable[google.api.httpbody_pb2.HttpBody, google.api.httpbody_pb2.HttpBody]

class IrisServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def Webhook(
        self,
        request: google.api.httpbody_pb2.HttpBody,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.api.httpbody_pb2.HttpBody: ...

def add_IrisServicer_to_server(servicer: IrisServicer, server: grpc.Server) -> None: ...
