# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: public_trips.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import annotations_pb2 as annotations__pb2
from . import api_pb2 as api__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12public_trips.proto\x12\x1dorg.couchers.api.public_trips\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x11\x61nnotations.proto\x1a\tapi.proto\"\x9b\x03\n\nPublicTrip\x12\x0f\n\x07trip_id\x18\x01 \x01(\x03\x12)\n\x04user\x18\x02 \x01(\x0b\x32\x1b.org.couchers.api.core.User\x12\x14\n\x0c\x63ommunity_id\x18\x03 \x01(\x03\x12\x11\n\tfrom_date\x18\x04 \x01(\t\x12\x0f\n\x07to_date\x18\x05 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x12?\n\x06status\x18\x07 \x01(\x0e\x32/.org.couchers.api.public_trips.PublicTripStatus\x12+\n\x07\x63reated\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x0e\x63ommunity_slug\x18\t \x01(\t\x12\x18\n\x10same_gender_only\x18\n \x01(\x08\x12\x19\n\x0coffers_count\x18\x0b \x01(\x05H\x00\x88\x01\x01\x12\x16\n\x0e\x63ommunity_name\x18\x0c \x01(\t\x12\x1e\n\x16viewer_host_request_id\x18\r \x01(\x03\x42\x0f\n\r_offers_count\"~\n\x13\x43reatePublicTripReq\x12\x14\n\x0c\x63ommunity_id\x18\x01 \x01(\x03\x12\x11\n\tfrom_date\x18\x02 \x01(\t\x12\x0f\n\x07to_date\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x18\n\x10same_gender_only\x18\x05 \x01(\x08\"#\n\x10GetPublicTripReq\x12\x0f\n\x07trip_id\x18\x01 \x01(\x03\"Q\n\x12ListPublicTripsReq\x12\x14\n\x0c\x63ommunity_id\x18\x01 \x01(\x03\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"n\n\x12ListPublicTripsRes\x12?\n\x0cpublic_trips\x18\x01 \x03(\x0b\x32).org.couchers.api.public_trips.PublicTrip\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xab\x01\n\x18ListPublicTripsByUserReq\x12\x0f\n\x07user_id\x18\x01 \x01(\x03\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x44\n\x0bstatuses_in\x18\x04 \x03(\x0e\x32/.org.couchers.api.public_trips.PublicTripStatus\x12\x11\n\tascending\x18\x05 \x01(\x08\"t\n\x18ListPublicTripsByUserRes\x12?\n\x0cpublic_trips\x18\x01 \x03(\x0b\x32).org.couchers.api.public_trips.PublicTrip\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x9d\x02\n\x13UpdatePublicTripReq\x12\x0f\n\x07trip_id\x18\x01 \x01(\x03\x12\x16\n\tfrom_date\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x14\n\x07to_date\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x18\n\x0b\x64\x65scription\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x44\n\x06status\x18\x05 \x01(\x0e\x32/.org.couchers.api.public_trips.PublicTripStatusH\x03\x88\x01\x01\x12\x1d\n\x10same_gender_only\x18\x06 \x01(\x08H\x04\x88\x01\x01\x42\x0c\n\n_from_dateB\n\n\x08_to_dateB\x0e\n\x0c_descriptionB\t\n\x07_statusB\x13\n\x11_same_gender_only*\x80\x01\n\x10PublicTripStatus\x12\"\n\x1ePUBLIC_TRIP_STATUS_UNSPECIFIED\x10\x00\x12)\n%PUBLIC_TRIP_STATUS_SEARCHING_FOR_HOST\x10\x01\x12\x1d\n\x19PUBLIC_TRIP_STATUS_CLOSED\x10\x02\x32\xf5\x04\n\x0bPublicTrips\x12s\n\x10\x43reatePublicTrip\x12\x32.org.couchers.api.public_trips.CreatePublicTripReq\x1a).org.couchers.api.public_trips.PublicTrip\"\x00\x12m\n\rGetPublicTrip\x12/.org.couchers.api.public_trips.GetPublicTripReq\x1a).org.couchers.api.public_trips.PublicTrip\"\x00\x12y\n\x0fListPublicTrips\x12\x31.org.couchers.api.public_trips.ListPublicTripsReq\x1a\x31.org.couchers.api.public_trips.ListPublicTripsRes\"\x00\x12\x8b\x01\n\x15ListPublicTripsByUser\x12\x37.org.couchers.api.public_trips.ListPublicTripsByUserReq\x1a\x37.org.couchers.api.public_trips.ListPublicTripsByUserRes\"\x00\x12s\n\x10UpdatePublicTrip\x12\x32.org.couchers.api.public_trips.UpdatePublicTripReq\x1a).org.couchers.api.public_trips.PublicTrip\"\x00\x1a\x04\x88\xb5\x18\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'public_trips_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_PUBLICTRIPS']._loaded_options = None
  _globals['_PUBLICTRIPS']._serialized_options = b'\210\265\030\003'
  _globals['_PUBLICTRIPSTATUS']._serialized_start=1471
  _globals['_PUBLICTRIPSTATUS']._serialized_end=1599
  _globals['_PUBLICTRIP']._serialized_start=117
  _globals['_PUBLICTRIP']._serialized_end=528
  _globals['_CREATEPUBLICTRIPREQ']._serialized_start=530
  _globals['_CREATEPUBLICTRIPREQ']._serialized_end=656
  _globals['_GETPUBLICTRIPREQ']._serialized_start=658
  _globals['_GETPUBLICTRIPREQ']._serialized_end=693
  _globals['_LISTPUBLICTRIPSREQ']._serialized_start=695
  _globals['_LISTPUBLICTRIPSREQ']._serialized_end=776
  _globals['_LISTPUBLICTRIPSRES']._serialized_start=778
  _globals['_LISTPUBLICTRIPSRES']._serialized_end=888
  _globals['_LISTPUBLICTRIPSBYUSERREQ']._serialized_start=891
  _globals['_LISTPUBLICTRIPSBYUSERREQ']._serialized_end=1062
  _globals['_LISTPUBLICTRIPSBYUSERRES']._serialized_start=1064
  _globals['_LISTPUBLICTRIPSBYUSERRES']._serialized_end=1180
  _globals['_UPDATEPUBLICTRIPREQ']._serialized_start=1183
  _globals['_UPDATEPUBLICTRIPREQ']._serialized_end=1468
  _globals['_PUBLICTRIPS']._serialized_start=1602
  _globals['_PUBLICTRIPS']._serialized_end=2231
# @@protoc_insertion_point(module_scope)
