"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import google.protobuf.wrappers_pb2
import postal_verification_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class CreateCommunityReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    PARENT_NODE_ID_FIELD_NUMBER: builtins.int
    ADMIN_IDS_FIELD_NUMBER: builtins.int
    GEOJSON_FIELD_NUMBER: builtins.int
    name: builtins.str
    description: builtins.str
    parent_node_id: builtins.int
    geojson: builtins.str
    @property
    def admin_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        name: builtins.str | None = ...,
        description: builtins.str | None = ...,
        parent_node_id: builtins.int | None = ...,
        admin_ids: collections.abc.Iterable[builtins.int] | None = ...,
        geojson: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["admin_ids", b"admin_ids", "description", b"description", "geojson", b"geojson", "name", b"name", "parent_node_id", b"parent_node_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___CreateCommunityReq: typing_extensions.TypeAlias = CreateCommunityReq

@typing.final
class UpdateCommunityReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMUNITY_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    PARENT_NODE_ID_FIELD_NUMBER: builtins.int
    GEOJSON_FIELD_NUMBER: builtins.int
    community_id: builtins.int
    name: builtins.str
    description: builtins.str
    parent_node_id: builtins.int
    geojson: builtins.str
    def __init__(
        self,
        *,
        community_id: builtins.int | None = ...,
        name: builtins.str | None = ...,
        description: builtins.str | None = ...,
        parent_node_id: builtins.int | None = ...,
        geojson: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["community_id", b"community_id", "description", b"description", "geojson", b"geojson", "name", b"name", "parent_node_id", b"parent_node_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___UpdateCommunityReq: typing_extensions.TypeAlias = UpdateCommunityReq

@typing.final
class ListEventCommunityInviteRequestsReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    page_size: builtins.int
    page_token: builtins.str
    def __init__(
        self,
        *,
        page_size: builtins.int | None = ...,
        page_token: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["page_size", b"page_size", "page_token", b"page_token"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListEventCommunityInviteRequestsReq: typing_extensions.TypeAlias = ListEventCommunityInviteRequestsReq

@typing.final
class EventCommunityInviteRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENT_COMMUNITY_INVITE_REQUEST_ID_FIELD_NUMBER: builtins.int
    USER_ID_FIELD_NUMBER: builtins.int
    EVENT_URL_FIELD_NUMBER: builtins.int
    APPROX_USERS_TO_NOTIFY_FIELD_NUMBER: builtins.int
    COMMUNITY_ID_FIELD_NUMBER: builtins.int
    event_community_invite_request_id: builtins.int
    user_id: builtins.int
    event_url: builtins.str
    approx_users_to_notify: builtins.int
    """assuming they have notifs enabled"""
    community_id: builtins.int
    def __init__(
        self,
        *,
        event_community_invite_request_id: builtins.int | None = ...,
        user_id: builtins.int | None = ...,
        event_url: builtins.str | None = ...,
        approx_users_to_notify: builtins.int | None = ...,
        community_id: builtins.int | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["approx_users_to_notify", b"approx_users_to_notify", "community_id", b"community_id", "event_community_invite_request_id", b"event_community_invite_request_id", "event_url", b"event_url", "user_id", b"user_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___EventCommunityInviteRequest: typing_extensions.TypeAlias = EventCommunityInviteRequest

@typing.final
class ListEventCommunityInviteRequestsRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REQUESTS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    @property
    def requests(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___EventCommunityInviteRequest]: ...
    def __init__(
        self,
        *,
        requests: collections.abc.Iterable[Global___EventCommunityInviteRequest] | None = ...,
        next_page_token: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["next_page_token", b"next_page_token", "requests", b"requests"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListEventCommunityInviteRequestsRes: typing_extensions.TypeAlias = ListEventCommunityInviteRequestsRes

@typing.final
class DecideEventCommunityInviteRequestReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENT_COMMUNITY_INVITE_REQUEST_ID_FIELD_NUMBER: builtins.int
    APPROVE_FIELD_NUMBER: builtins.int
    event_community_invite_request_id: builtins.int
    approve: builtins.bool
    """whether to approve or deny it"""
    def __init__(
        self,
        *,
        event_community_invite_request_id: builtins.int | None = ...,
        approve: builtins.bool | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["approve", b"approve", "event_community_invite_request_id", b"event_community_invite_request_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___DecideEventCommunityInviteRequestReq: typing_extensions.TypeAlias = DecideEventCommunityInviteRequestReq

@typing.final
class DecideEventCommunityInviteRequestRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___DecideEventCommunityInviteRequestRes: typing_extensions.TypeAlias = DecideEventCommunityInviteRequestRes

@typing.final
class SendBlogPostNotificationReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    BLURB_FIELD_NUMBER: builtins.int
    url: builtins.str
    title: builtins.str
    blurb: builtins.str
    def __init__(
        self,
        *,
        url: builtins.str | None = ...,
        title: builtins.str | None = ...,
        blurb: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["blurb", b"blurb", "title", b"title", "url", b"url"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___SendBlogPostNotificationReq: typing_extensions.TypeAlias = SendBlogPostNotificationReq

@typing.final
class MakeUserVolunteerReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    STARTED_VOLUNTEERING_FIELD_NUMBER: builtins.int
    HIDE_ON_TEAM_PAGE_FIELD_NUMBER: builtins.int
    user_id: builtins.int
    role: builtins.str
    started_volunteering: builtins.str
    """date as "yyyy-mm-dd", defaults to today if not provided"""
    hide_on_team_page: builtins.bool
    """defaults to false (i.e., show on team page by default)"""
    def __init__(
        self,
        *,
        user_id: builtins.int | None = ...,
        role: builtins.str | None = ...,
        started_volunteering: builtins.str | None = ...,
        hide_on_team_page: builtins.bool | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["hide_on_team_page", b"hide_on_team_page", "role", b"role", "started_volunteering", b"started_volunteering", "user_id", b"user_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___MakeUserVolunteerReq: typing_extensions.TypeAlias = MakeUserVolunteerReq

@typing.final
class UpdateVolunteerReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    SORT_KEY_FIELD_NUMBER: builtins.int
    STARTED_VOLUNTEERING_FIELD_NUMBER: builtins.int
    STOPPED_VOLUNTEERING_FIELD_NUMBER: builtins.int
    SHOW_ON_TEAM_PAGE_FIELD_NUMBER: builtins.int
    REINSTATE_VOLUNTEER_FIELD_NUMBER: builtins.int
    user_id: builtins.int
    reinstate_volunteer: builtins.bool
    """if true, clears stopped_volunteering (reinstates a former volunteer as current); cannot be combined with setting stopped_volunteering"""
    @property
    def role(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def sort_key(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    @property
    def started_volunteering(self) -> google.protobuf.wrappers_pb2.StringValue:
        """dates as "yyyy-mm-dd" """

    @property
    def stopped_volunteering(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def show_on_team_page(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    def __init__(
        self,
        *,
        user_id: builtins.int | None = ...,
        role: google.protobuf.wrappers_pb2.StringValue | None = ...,
        sort_key: google.protobuf.wrappers_pb2.DoubleValue | None = ...,
        started_volunteering: google.protobuf.wrappers_pb2.StringValue | None = ...,
        stopped_volunteering: google.protobuf.wrappers_pb2.StringValue | None = ...,
        show_on_team_page: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        reinstate_volunteer: builtins.bool | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["role", b"role", "show_on_team_page", b"show_on_team_page", "sort_key", b"sort_key", "started_volunteering", b"started_volunteering", "stopped_volunteering", b"stopped_volunteering"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["reinstate_volunteer", b"reinstate_volunteer", "role", b"role", "show_on_team_page", b"show_on_team_page", "sort_key", b"sort_key", "started_volunteering", b"started_volunteering", "stopped_volunteering", b"stopped_volunteering", "user_id", b"user_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___UpdateVolunteerReq: typing_extensions.TypeAlias = UpdateVolunteerReq

@typing.final
class ListVolunteersReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INCLUDE_PAST_FIELD_NUMBER: builtins.int
    include_past: builtins.bool
    """if true, include past volunteers (where stopped_volunteering is set)"""
    def __init__(
        self,
        *,
        include_past: builtins.bool | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["include_past", b"include_past"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListVolunteersReq: typing_extensions.TypeAlias = ListVolunteersReq

@typing.final
class Volunteer(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    IS_BOARD_MEMBER_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    IMG_FIELD_NUMBER: builtins.int
    SORT_KEY_FIELD_NUMBER: builtins.int
    STARTED_VOLUNTEERING_FIELD_NUMBER: builtins.int
    STOPPED_VOLUNTEERING_FIELD_NUMBER: builtins.int
    SHOW_ON_TEAM_PAGE_FIELD_NUMBER: builtins.int
    LINK_TYPE_FIELD_NUMBER: builtins.int
    LINK_TEXT_FIELD_NUMBER: builtins.int
    LINK_URL_FIELD_NUMBER: builtins.int
    user_id: builtins.int
    name: builtins.str
    """display name"""
    username: builtins.str
    """couchers username"""
    is_board_member: builtins.bool
    """whether the user is a board member (and director)"""
    role: builtins.str
    """volunteer defined role"""
    location: builtins.str
    """location from profile"""
    img: builtins.str
    """avatar from profile"""
    sort_key: builtins.float
    """custom sort order on team page, sorted ascending"""
    started_volunteering: builtins.str
    """dates as "yyyy-mm-dd" """
    stopped_volunteering: builtins.str
    """dates as "yyyy-mm-dd" """
    show_on_team_page: builtins.bool
    link_type: builtins.str
    """link type, one of couchers, email, linkedin, website"""
    link_text: builtins.str
    """the text to be shown on the link"""
    link_url: builtins.str
    """the URL the link should take you to"""
    def __init__(
        self,
        *,
        user_id: builtins.int | None = ...,
        name: builtins.str | None = ...,
        username: builtins.str | None = ...,
        is_board_member: builtins.bool | None = ...,
        role: builtins.str | None = ...,
        location: builtins.str | None = ...,
        img: builtins.str | None = ...,
        sort_key: builtins.float | None = ...,
        started_volunteering: builtins.str | None = ...,
        stopped_volunteering: builtins.str | None = ...,
        show_on_team_page: builtins.bool | None = ...,
        link_type: builtins.str | None = ...,
        link_text: builtins.str | None = ...,
        link_url: builtins.str | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["_link_text", b"_link_text", "_link_type", b"_link_type", "_link_url", b"_link_url", "_sort_key", b"_sort_key", "_stopped_volunteering", b"_stopped_volunteering", "link_text", b"link_text", "link_type", b"link_type", "link_url", b"link_url", "sort_key", b"sort_key", "stopped_volunteering", b"stopped_volunteering"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["_link_text", b"_link_text", "_link_type", b"_link_type", "_link_url", b"_link_url", "_sort_key", b"_sort_key", "_stopped_volunteering", b"_stopped_volunteering", "img", b"img", "is_board_member", b"is_board_member", "link_text", b"link_text", "link_type", b"link_type", "link_url", b"link_url", "location", b"location", "name", b"name", "role", b"role", "show_on_team_page", b"show_on_team_page", "sort_key", b"sort_key", "started_volunteering", b"started_volunteering", "stopped_volunteering", b"stopped_volunteering", "user_id", b"user_id", "username", b"username"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
    _WhichOneofReturnType__link_text: typing_extensions.TypeAlias = typing.Literal["link_text"]
    _WhichOneofArgType__link_text: typing_extensions.TypeAlias = typing.Literal["_link_text", b"_link_text"]
    _WhichOneofReturnType__link_type: typing_extensions.TypeAlias = typing.Literal["link_type"]
    _WhichOneofArgType__link_type: typing_extensions.TypeAlias = typing.Literal["_link_type", b"_link_type"]
    _WhichOneofReturnType__link_url: typing_extensions.TypeAlias = typing.Literal["link_url"]
    _WhichOneofArgType__link_url: typing_extensions.TypeAlias = typing.Literal["_link_url", b"_link_url"]
    _WhichOneofReturnType__sort_key: typing_extensions.TypeAlias = typing.Literal["sort_key"]
    _WhichOneofArgType__sort_key: typing_extensions.TypeAlias = typing.Literal["_sort_key", b"_sort_key"]
    _WhichOneofReturnType__stopped_volunteering: typing_extensions.TypeAlias = typing.Literal["stopped_volunteering"]
    _WhichOneofArgType__stopped_volunteering: typing_extensions.TypeAlias = typing.Literal["_stopped_volunteering", b"_stopped_volunteering"]
    @typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__link_text) -> _WhichOneofReturnType__link_text | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__link_type) -> _WhichOneofReturnType__link_type | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__link_url) -> _WhichOneofReturnType__link_url | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__sort_key) -> _WhichOneofReturnType__sort_key | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__stopped_volunteering) -> _WhichOneofReturnType__stopped_volunteering | None: ...

Global___Volunteer: typing_extensions.TypeAlias = Volunteer

@typing.final
class ListVolunteersRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VOLUNTEERS_FIELD_NUMBER: builtins.int
    @property
    def volunteers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___Volunteer]: ...
    def __init__(
        self,
        *,
        volunteers: collections.abc.Iterable[Global___Volunteer] | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["volunteers", b"volunteers"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListVolunteersRes: typing_extensions.TypeAlias = ListVolunteersRes

@typing.final
class ListPostcardsReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    page_size: builtins.int
    page_token: builtins.str
    def __init__(
        self,
        *,
        page_size: builtins.int | None = ...,
        page_token: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["page_size", b"page_size", "page_token", b"page_token"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListPostcardsReq: typing_extensions.TypeAlias = ListPostcardsReq

@typing.final
class PostcardInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POSTAL_VERIFICATION_ATTEMPT_ID_FIELD_NUMBER: builtins.int
    USER_ID_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    ADDRESS_FIELD_NUMBER: builtins.int
    CREATED_FIELD_NUMBER: builtins.int
    POSTCARD_SENT_AT_FIELD_NUMBER: builtins.int
    VERIFIED_AT_FIELD_NUMBER: builtins.int
    postal_verification_attempt_id: builtins.int
    user_id: builtins.int
    username: builtins.str
    name: builtins.str
    status: postal_verification_pb2.PostalVerificationStatus.ValueType
    @property
    def address(self) -> postal_verification_pb2.PostalAddress: ...
    @property
    def created(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def postcard_sent_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def verified_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        postal_verification_attempt_id: builtins.int | None = ...,
        user_id: builtins.int | None = ...,
        username: builtins.str | None = ...,
        name: builtins.str | None = ...,
        status: postal_verification_pb2.PostalVerificationStatus.ValueType | None = ...,
        address: postal_verification_pb2.PostalAddress | None = ...,
        created: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        postcard_sent_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        verified_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["address", b"address", "created", b"created", "postcard_sent_at", b"postcard_sent_at", "verified_at", b"verified_at"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["address", b"address", "created", b"created", "name", b"name", "postal_verification_attempt_id", b"postal_verification_attempt_id", "postcard_sent_at", b"postcard_sent_at", "status", b"status", "user_id", b"user_id", "username", b"username", "verified_at", b"verified_at"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___PostcardInfo: typing_extensions.TypeAlias = PostcardInfo

@typing.final
class ListPostcardsRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POSTCARDS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    @property
    def postcards(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___PostcardInfo]: ...
    def __init__(
        self,
        *,
        postcards: collections.abc.Iterable[Global___PostcardInfo] | None = ...,
        next_page_token: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["next_page_token", b"next_page_token", "postcards", b"postcards"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListPostcardsRes: typing_extensions.TypeAlias = ListPostcardsRes

@typing.final
class DownloadPostcardPdfReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POSTAL_VERIFICATION_ATTEMPT_ID_FIELD_NUMBER: builtins.int
    postal_verification_attempt_id: builtins.int
    def __init__(
        self,
        *,
        postal_verification_attempt_id: builtins.int | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["postal_verification_attempt_id", b"postal_verification_attempt_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___DownloadPostcardPdfReq: typing_extensions.TypeAlias = DownloadPostcardPdfReq

@typing.final
class DownloadPostcardPdfRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PDF_FIELD_NUMBER: builtins.int
    pdf: builtins.bytes
    def __init__(
        self,
        *,
        pdf: builtins.bytes | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["pdf", b"pdf"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___DownloadPostcardPdfRes: typing_extensions.TypeAlias = DownloadPostcardPdfRes
