"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetTermsOfServiceRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TERMS_OF_SERVICE_FIELD_NUMBER: builtins.int
    terms_of_service: builtins.str
    """CommonMark without images"""
    def __init__(
        self,
        *,
        terms_of_service: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["terms_of_service", b"terms_of_service"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___GetTermsOfServiceRes: typing_extensions.TypeAlias = GetTermsOfServiceRes

@typing.final
class CommunityGuideline(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    GUIDELINE_FIELD_NUMBER: builtins.int
    ICON_SVG_FIELD_NUMBER: builtins.int
    title: builtins.str
    guideline: builtins.str
    icon_svg: builtins.str
    def __init__(
        self,
        *,
        title: builtins.str | None = ...,
        guideline: builtins.str | None = ...,
        icon_svg: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["guideline", b"guideline", "icon_svg", b"icon_svg", "title", b"title"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___CommunityGuideline: typing_extensions.TypeAlias = CommunityGuideline

@typing.final
class GetCommunityGuidelinesRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMUNITY_GUIDELINES_FIELD_NUMBER: builtins.int
    @property
    def community_guidelines(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___CommunityGuideline]: ...
    def __init__(
        self,
        *,
        community_guidelines: collections.abc.Iterable[Global___CommunityGuideline] | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["community_guidelines", b"community_guidelines"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___GetCommunityGuidelinesRes: typing_extensions.TypeAlias = GetCommunityGuidelinesRes

@typing.final
class Region(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALPHA3_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    alpha3: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        alpha3: builtins.str | None = ...,
        name: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["alpha3", b"alpha3", "name", b"name"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___Region: typing_extensions.TypeAlias = Region

@typing.final
class GetRegionsRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REGIONS_FIELD_NUMBER: builtins.int
    @property
    def regions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___Region]: ...
    def __init__(
        self,
        *,
        regions: collections.abc.Iterable[Global___Region] | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["regions", b"regions"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___GetRegionsRes: typing_extensions.TypeAlias = GetRegionsRes

@typing.final
class Language(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CODE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    code: builtins.str
    """ISO639-3 lowercase language code"""
    name: builtins.str
    def __init__(
        self,
        *,
        code: builtins.str | None = ...,
        name: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["code", b"code", "name", b"name"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___Language: typing_extensions.TypeAlias = Language

@typing.final
class GetLanguagesRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LANGUAGES_FIELD_NUMBER: builtins.int
    @property
    def languages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___Language]: ...
    def __init__(
        self,
        *,
        languages: collections.abc.Iterable[Global___Language] | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["languages", b"languages"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___GetLanguagesRes: typing_extensions.TypeAlias = GetLanguagesRes

@typing.final
class Badge(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    COLOR_FIELD_NUMBER: builtins.int
    id: builtins.str
    name: builtins.str
    description: builtins.str
    color: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str | None = ...,
        name: builtins.str | None = ...,
        description: builtins.str | None = ...,
        color: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["color", b"color", "description", b"description", "id", b"id", "name", b"name"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___Badge: typing_extensions.TypeAlias = Badge

@typing.final
class GetBadgesRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BADGES_FIELD_NUMBER: builtins.int
    @property
    def badges(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___Badge]: ...
    def __init__(
        self,
        *,
        badges: collections.abc.Iterable[Global___Badge] | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["badges", b"badges"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___GetBadgesRes: typing_extensions.TypeAlias = GetBadgesRes
