# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import dashboard_pb2 as dashboard__pb2


class DashboardStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetDashboardV2 = channel.unary_unary(
                '/org.couchers.api.dashboard.Dashboard/GetDashboardV2',
                request_serializer=dashboard__pb2.GetDashboardV2Req.SerializeToString,
                response_deserializer=dashboard__pb2.GetDashboardV2Res.FromString,
                )


class DashboardServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetDashboardV2(self, request, context):
        """Fetch all the content needed to render the dashboard in a single call, instead of fanning out
        to the individual RPCs. Each field mirrors the response of the RPC that previously populated it.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DashboardServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetDashboardV2': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDashboardV2,
                    request_deserializer=dashboard__pb2.GetDashboardV2Req.FromString,
                    response_serializer=dashboard__pb2.GetDashboardV2Res.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'org.couchers.api.dashboard.Dashboard', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Dashboard(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetDashboardV2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.dashboard.Dashboard/GetDashboardV2',
            dashboard__pb2.GetDashboardV2Req.SerializeToString,
            dashboard__pb2.GetDashboardV2Res.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
