from sqlalchemy import orm
from couchers.context import CouchersContext
"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Messages between main and media server"""

import abc
import collections.abc
import google.protobuf.empty_pb2
import grpc
import grpc.aio
import media_pb2
import typing


GRPC_GENERATED_VERSION: str
GRPC_VERSION: str

class MediaStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    UploadConfirmation: grpc.UnaryUnaryMultiCallable[media_pb2.UploadConfirmationReq, google.protobuf.empty_pb2.Empty]
    """when an upload completes, the upload server confirms to the main server
    that the upload succeeded using this function
    """

class MediaServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def UploadConfirmation(
        self,
        request: media_pb2.UploadConfirmationReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.protobuf.empty_pb2.Empty:
        """when an upload completes, the upload server confirms to the main server
        that the upload succeeded using this function
        """

def add_MediaServicer_to_server(servicer: MediaServicer, server: grpc.Server) -> None: ...
